#=============================================================================
# RNA Configuration File
#=============================================================================
#
#=============================================================================
# Copyright (C) 2003	Ikki Ohmukai,		All rights reserved.
# Copyright (C) 2003	Masahiro Hamasaki,	All rights reserved.
#
#
# This file is part of RNA.
#
#	RNA is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	RNA is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with RNA; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#=============================================================================

package RNA::Config;
use strict;
#use lib qw(lib extlib);
use RNA;
my $VERSION = $RNA::VERSION;
use vars qw($antenna_owner $base_uri $background_update 
	$link_trace $accumulative_link_trace 
	$auth_file $auth_mode
	$auth_configure_cgi $auth_rna_cgi $auth_cache_cgi 
	$auth_clip_cgi $auth_alliance_cgi $auth_foaf_cgi
	$weblog_uri $weblog_xmlrpc_uri $weblog_id
	$foaf_rdf $foaf_uri 
	$main_index_title $main_index_description $foaf_cgi_uri 
	$recent_site_title $recent_site_description 
	$num_recent_article $recent_entry_title $recent_entry_description 
	$num_per_site $recent_site_entry_title $recent_site_entry_description 
	$clip_list_title $clip_list_description
);

#-----------------------------------------------------------------------------
# 基本設定（必須）
# Basic Settings (require)
#-----------------------------------------------------------------------------

# あなたのお名前
# Your name
# $antenna_owner = 'i2k';
$antenna_owner = "your_name";

# RNAを設置するURI
# Base URI (directory) of your RNA
$base_uri = 'http://www-kasm.nii.ac.jp/~msano/rna/';
# $base_uri = 'http://www-kasm.nii.ac.jp/~i2k/tmp/rna/';
# $base_uri = 'http://foo.bar.com/rna/';


#------------------------------------
# RNA機能拡張
# RNA Extensions
#------------------------------------

# バックグラウンド処理
#	アンテナの更新処理が完了する前にブラウザへのレスポンスを行います．
#	この設定を行うとブラウザからのリクエストと実際の更新の間に時間差が生じます．
#	※ UNIX系サーバでのみ設定可能です．
#	1: 使用する	0: 使用しない（アンテナの更新処理が完了するまでブラウザが待たされます）
# Background Processing (available in Unix-based server)
#	1: enable	0: disable
$background_update = 1;

# リンク・TrackBackの抽出と表示
#	チェック対象の記事にリンクもしくはTrackBackが存在した場合に
#	これらのリンクを同時に表示します．
#	※ TrackBack抽出はMovableTypeで構築されたサイトのみが対象になります．
#	1: 使用する	0: 使用しない
# Link / TrackBack Tracing
#	1: enable	0: disable
$link_trace = 1;
$accumulative_link_trace = 1;

#------------------------------------
# 認証
# Authentication Settings
#------------------------------------

# 認証機能の有効/無効
# Activate Authentication
#	1: enable	0: disable
$auth_configure_cgi = 1;
$auth_rna_cgi = 0;
$auth_cache_cgi = 0;
$auth_clip_cgi = 1;
$auth_alliance_cgi = 1;
$auth_foaf_cgi = 1;

# パスワードファイルの指定
# Password File
$auth_file = 'etc/.rna-passwd'; # recommend to change...

# Authentication Mode
$auth_mode = 'file'; # file, weblog


#------------------------------------
# Your Weblog 
#------------------------------------
$weblog_uri = ''; 
$weblog_xmlrpc_uri = '';
$weblog_id = 1;


#------------------------------------
# FOAF - friend of a friend
#------------------------------------
$foaf_rdf = 'foaf.rdf';
$foaf_uri = $base_uri . $foaf_rdf;


#------------------------------------
# 各ページのURI設定
# URI Settings
#------------------------------------

# トップページ
# Index Page
$main_index_title  = 'RNA::Personal RDF Suite';
$main_index_description 
	= 'Version '. $VERSION . ' by semblog.org';

# FOAF用CGI
# FOAF CGI
$foaf_cgi_uri = $base_uri . 'foaf.cgi';


#------------------------------------
# サイトのリスト（dc:date順にソート）
# RSS Updated Sites (ordered by dc:date)
#------------------------------------

$recent_site_title       = 'RNA::Updated Sites';
$recent_site_description = 'RSS Site List with Chronological Order';

#------------------------------------
# 最新記事のリスト
# RSS Recent Entries (ordered by dc:date)
#------------------------------------

$num_recent_article = 100;
$recent_entry_title = 'RNA::Recent Entries';
$recent_entry_description =
	'Newest ' . $num_recent_article . ' Entries';

#------------------------------------
# サイトごとの最新記事リスト
# RSS Recent Entries Classified by Sites
#------------------------------------

$num_per_site = '5';
$recent_site_entry_title = 'RNA::Recent Sites/Entries';
$recent_site_entry_description =
	'Newest '. $num_per_site . ' Entries of Each Site';

#------------------------------------
# クリップ記事のリスト
# RSS Clipped Entries
#------------------------------------

$clip_list_title = 'RNA::Clipped Entries';
$clip_list_description = 'Newest Clipped Entries';


#=============================================================================
1;
