#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
# RNA 連携
# 	将来的には、Alliance::Recommend, Alliance::Method, Alliance::Application などに分割予定
#
#==============================================================================


package RNA::Alliance;

use strict;
use Carp;
use RNA::Utils qw(:all);
use RNA::FOAF;
use RNA::RSS;
use RNA::AntennaTree;

use vars qw($VERSION);

$VERSION = '0.1';

# $alliance = new RNA::Alliance(RNA=>$rna);
sub new {
	my $class = shift;
	my $self = {};
	
	bless $self, $class;
	
	$self->init(@_);
	
	return $self;
}


sub init {
	my $self = shift;
	my %arg = @_;

	croak "RNA must be associated." unless($arg{RNA});
	$self->rna($arg{RNA});

	$self->{FriendRNAs} = {};
	# $self->{FriendRNAs} = {
	#	'rna URI 1' => {
	#		AlternateRSS => $rna_rss,     # RNA::RSS
	#		SiteListRSS  => $site_list_rss, # RNA::RSS
	#		ClipListRSS  => $clip_list_rss, # RNA::RSS
	#	},
	#	'rna URI 2' => {
	#	},
	#	...
	#};

	$self->{RecommendedSiteList} = {
		RSS      => {},
		AntennaTree => {}
	};
	$self->{SimilarityList} = {
		RSS      => {},
		AntennaTree => {}
	};

}


# $self->rna($rna);
sub rna
{
	my $self = shift;

	if(@_) {
		$self->{_rna} = shift;
	}
	else {
		croak "RNA is not associated." unless($self->{_rna});
		return $self->{_rna}; 
	}
}


# my $str = $self->http_get(uri=>$uri);
sub http_get
{
	my $self = shift;
	my $config = $self->rna->{Config};
	my %arg = @_;
	
	my ($str, $headers) 
		= &get_html(uri=>$arg{uri}, timeout=>$config->{Timeout}, ua=>$RNA::NAME);

	&convert_char_code(\$str, $config->{Encoding});
	return $str;
}

# $foaf = $self->get_foaf;
#	$foaf : RNA::FOAF
sub get_foaf
{
	my $self = shift;
	my $config = $self->rna->{Config};
	
	my $foaf_str = $self->http_get(uri=>$config->{FOAF}->{URI});

	my $foaf = new RNA::FOAF;
	eval {$foaf->parse($foaf_str);};
	if($@) {
		croak ("Invalid FOAF file : " . $config->{FOAF}->{URI} . "\n");
		return undef;
	}
	else {
		return $foaf;
	}
}

# my $rna_uris_ref = $self->get_friend_rna_uris;
sub get_friend_rna_uris
{
	my $self = shift;

	my $foaf = $self->get_foaf;
	my @knows = @{$foaf->person->knows};

	my @list = ();
	foreach my $p (@knows) {
		push(@list, $p->rna) if($p->rna);
	}

	return \@list;
}

# $rss = $self->get_rna_info($rna_uri);
sub get_rna_info
{
	my $self = shift;
	my $rna_uri = shift;

	# RNAトップページ取得
	my $html_str = $self->http_get(uri=>$rna_uri);
	my $link = RNA::AutoDiscovery->new(html=>$html_str)
				->search_alternate('title', 'RSS');
	my $rss_uri = $link->{href} ? $link->{href} : $rna_uri . 'index.rdf';

	my $rss_str = $self->http_get(uri=>$rss_uri);
	my $rss = new RNA::RSS;
	if($rss_str) {
		$rss->parse($rss_str);
	}
	else {
	# index.rdf が無い（古いバージョンのRNA）場合
		my ($title) = ($html_str =~ /<title>(.+?)<\/title>/si);
		$rss->channel(title=>$title, link=>$rna_uri);
	}

	return $rss;
}

# $site_list_rss = $self->get_site_list_rss($rna_rss);
sub get_site_list_rss
{
	my $self = shift;
	my $config = $self->rna->{Config};
	my $rna_rss = shift;

	my $site_list_rss = new RNA::RSS;
	my $uri = '';
	foreach (@{$rna_rss->{items}}) {
		if('SiteList' eq $_->{dc}->{subject}) {
			$uri = $_->{link};
			last;
		}
	}
	unless($uri) {
		my $link = $rna_rss->{channel}->{link};
		$link =~ s/\/[^\/]+?$/\//;
		$uri = $link . $config->{SiteList}->{File} ;
		
	}
	
	my $str = $self->http_get(uri=>$uri);
	$site_list_rss->parse($str);

	return $site_list_rss;
}

# # $self->set_friends_rna;
sub set_friends_rna
{
	my $self = shift;
	my $config = $self->rna->{Config};

	# Friend's RNA のリスト取得
	my $rna_uris_ref = $self->get_friend_rna_uris;
	
	foreach my $rna_uri (@{$rna_uris_ref}) {
		my $rna_rss = $self->get_rna_info($rna_uri);
		my $site_list_rss = $self->get_site_list_rss($rna_rss);

		# はてなをはずす。
		@{$site_list_rss->{items}} 
			= grep {$_->{dc}->{subject} ne $config->{HatenaFlag}} 
				@{$site_list_rss->{items}};

		$self->{FriendRNAs}->{$rna_uri} =
			{
				AlternateRSS => $rna_rss,     # RNA::RSS
				SiteListRSS  => $site_list_rss, # RNA::RSS
				ClipListRSS  => undef, # RNA::RSS
			};
	}
}

#-----------------------------------------------------------------------------
# Site Reccomendation
#-----------------------------------------------------------------------------

# $s = $self->calc_similarity_site_list($list_rss1, $list_rss2);
sub calc_similarity_site_list
{
	my $self = shift;
	my ($list_rss1, $list_rss2) = @_;

	# list1 にあるもの
	my %exist_list1 = ();
	map {$exist_list1{$_->{link}} = 1;} @{$list_rss1->{items}};

	# 共通部分を探す。
	my $count = 0;
	foreach (@{$list_rss2->{items}}) {
		++$count if($exist_list1{$_->{link}});
	}

	my $n1 = scalar(@{$list_rss1->{items}});
	my $n2 = scalar(@{$list_rss2->{items}});

	return $count * 2 / ($n1 + $n2);
}


# Score リストに、URI リストに score を付加して加算
# 
# $self->_add_score($score_list_ref, $score, $uri_list_ref);
#	$score_list_ref = {
#		uri1 => score1,
#		uri2 => score2,
#		...
#	}
#	$uri_list_ref = ['uri1', 'uri3', 'uri6', ...]
#
sub _add_score{
	my $self = shift;
	my ($score_list_ref, $score, $uri_list_ref) = @_;

	# 加算ロジック
	foreach (@{$uri_list_ref}) {
		$score_list_ref->{$_} += $score;

	}
}


#
# $self->make_recomended_site_list;
sub make_recomended_site_list
{
	my $self = shift;
	my $config = $self->rna->{Config};

	# 自分のサイトリスト
	my $my_rna_rss = new RNA::RSS;
	$my_rna_rss->parsefile($config->{MainIndex}->{RSS});
	my $my_site_list_rss = $self->get_site_list_rss($my_rna_rss);

	$self->set_friends_rna;

	#-----------------------
	# calc similarity
	#-----------------------
	my $similarlity_rss = new RNA::RSS;
	$similarlity_rss->channel(
		title      =>$config->{SimilarityList}->{Title},
		link       =>$config->{BaseURI} . $config->{SimilarityList}->{RSS},
		description=>$config->{SimilarityList}->{Description},
		dc => {
			language => $config->{Language},
			date     => $self->rna->{Date},
			creator  => $config->{Owner},
		},
	);

	# 各 Friend RNA に対して、スコアを算出
	my %score_list = ();
	foreach my $rna_uri (keys %{$self->{FriendRNAs}}) {
		my $rna_rss       = $self->{FriendRNAs}->{$rna_uri}->{AlternateRSS};
		my $site_list_rss = $self->{FriendRNAs}->{$rna_uri}->{SiteListRSS};
		
		my $score = $self->calc_similarity_site_list(
					$my_site_list_rss, $site_list_rss);

		# score の切捨て（小数 第3位）
		$score = int($score * (10 ** 3)) / (10 ** 3);

		# URI ベースのスコアの加算
		my @site_uris = map {$_->{link}} @{$site_list_rss->{items}};
		$self->_add_score(\%score_list, $score, \@site_uris);

		my %item = %{$rna_rss->{channel}};
		$item{semblog} = {score => $score};
		$similarlity_rss->add_item(%item);
	}

	$self->{SimilarityList}->{RSS} = $similarlity_rss;

	#--------------------------------
	# URI ごとのスコアリスト
	#--------------------------------
	my $site_score_rss = new RNA::RSS;
	$site_score_rss->channel(
		title      =>$config->{RecommendedSiteList}->{Title},
		link   => $config->{BaseURI} . $config->{RecommendedSiteList}->{HTML},
		description => $config->{RecommendedSiteList}->{Description},
		dc => {
			language => $config->{Language},
			date     => $self->rna->{Date},
			creator  => $config->{Owner},
		},
	);
	# Local RNA Site List にあるものリスト
	my %exist_site = ();
	map {$exist_site{$_->{link}} = 1;} @{$my_site_list_rss->{items}};
	# スコア降順でソートしたサイトURIリスト
	my @sorted_site_uris 
		= sort {$score_list{$b} <=> $score_list{$a}} keys %score_list;
	foreach my $site_uri (@sorted_site_uris) {
		my $score = $score_list{$site_uri};

		# Local RNA にあるものははずす
		next if($exist_site{$site_uri});

		my %item = (
			title => $config->empty_value,
			link  => $site_uri,
			semblog => {
				score => $score,
			},
		);
		
		$site_score_rss->add_item(%item);
	}
	$self->{RecommendedSiteList}->{RSS} = $site_score_rss;

	# AntennaTree 
	my $antenna = new RNA::AntennaTree;
	$antenna->set_from_rss($site_score_rss);
	$self->{RecommendedSiteList}->{AntennaTree} = $antenna;
}



sub print_recommended_site_list
{
	my $self = shift;
	my $config = $self->rna->{Config};

	#----------------------------
	# SimilarityList
	#----------------------------

	# RSS
	my $similarity_str = $self->{SimilarityList}->{RSS}->as_string;
	&print_file($config->{SimilarityList}->{RSS}, \$similarity_str);

	#----------------------------
	# RecommendedSiteList
	#----------------------------

	{
		# RSS
		my $str = $self->{RecommendedSiteList}->{RSS}->as_string;
		&print_file($config->{RecommendedSiteList}->{RSS}, \$str);

		# HTML
		my $antenna = $self->{RecommendedSiteList}->{AntennaTree};
		my $template = &read_file($config->{Template}->{RecommendedSiteList});
		my $str_ref = $antenna->apply_template($template, 
			$config->{Template}->{Element});

		&print_file($config->{RecommendedSiteList}->{HTML}, $str_ref);
	}
}



#=============================================================================
1;

