package RNA::Atom::Feed;
#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
#
# 　Atom 仕様ドラフト
#	http://www.intertwingly.net/wiki/pie/Syntax
#=============================================================================

use strict;
use Carp;
use RNA::Utils;
use XML::SAX::PurePerl;
use vars qw($VERSION);

$VERSION = '0.1';

my $DEFAULT_VERSION = '0.3';
my $DEFAULT_ENCODING = 'UTF-8';
my $NAMESPACE = "http://purl.org/atom/ns#";

my %atom_field = (
	feed => {
		title => '',
		link => '',  # <link rel="alternate" type="text/html" href="http://site/url/"/>
		modified => '', # 2004-01-02T03:04:05Z

		author => {
			name => '', # '著者名'
			url  => '', # 'http://homepage/url/',
			email => '' # 'mail@example.com'
		},

		tagline => '', # 記述

		#id => '', 
	},
	entries => [], # each <entry>
	#entries => [
	#	{
	#		title => '', # タイトル１
	#		link =>  '', # rel="alternate" のもののみ
	#		modified => '', #2004-01-02T03:04:05Z
	#		issued => '', # 正式発表？の日
	#		id  => '', # ID1
	#		summary =>  '', #  type="text/plain">サマリー１...
	#		content => '', # type="text/html" mode="escaped"
	#	},
	#	{
	#		title => '', # タイトル１
	#		link =>  '', # rel="alternate" のもののみ
	#		...
	#	},
	#]
);

my $modules = {
	#'http://purl.org/rss/1.0/modules/syndication/' => 'syn',
	'http://purl.org/dc/elements/1.1/' => 'dc',
	'http://purl.org/dc/terms/' => 'dcterms',
	#'http://madskills.com/public/xml/rss/module/trackback/' => 'trackback',
	#'http://purl.org/rss/1.0/modules/aggregation/' => 'ag',
};



sub new {
    my $class = shift;
	my $self = {};
    
    bless $self, $class;
    
    $self->init(@_);
    
    return $self;
}


sub init {
    my $self = shift;
    my %hash = @_;

	%{$self} = %atom_field;
	
    # modules
    $self->{modules} = {};

    #get version info
    (exists($hash{version}))
	? ($self->{version} = $hash{version})
	    : ($self->{version} = $DEFAULT_VERSION);

    # encoding
    (exists($hash{encoding}))
	? ($self->{encoding} = $hash{encoding})
	    : ($self->{encoding} = $DEFAULT_ENCODING);
}

#sub add_module {
#    my $self = shift;
#    my $hash = {@_};
#
#    $hash->{prefix} =~ /^[a-z_][a-z0-9.-_]*$/ or
#    croak "a namespace prefix should look like [a-z_][a-z0-9.-_]*";
#
#    $hash->{uri} or
#    croak "a URI must be provided in a namespace declaration";
#
#	  $self->{modules}->{$hash->{uri}} = $hash->{prefix};
#}

# $str = RNA::Atom::empty_value;
sub empty_value
{
	return '-';
}



# experimental  !!!
sub as_string {
	my $self = shift;
	my $version = $self->{version};
	my $encoding = $self->{encoding};	
	my $output = '';

	$output .= qq(<?xml version="1.0" encoding="$encoding" ?>
<feed version="$version" xmlns="$NAMESPACE">
);

	my $feed = $self->{feed};
	while(my ($el, $val) = each %{$feed}) {
		next unless ($feed->{$el});
		if($el eq 'author') {
			$output .= "\t<author>\n";
			while(my ($ael, $aval) = each %{$val}) {
				$output .= "\t\t<$el>" . encode($val) . "</$el>\n";
			}
			$output .= "\t</author>\n";
		}
		elsif($el eq 'link') {
		# <link rel="alternate" type="text/html" href="http://site/url/"/>
			$output .= qq(\t<$el rel="alternate" type="text/html" href=")
					 . encode($val) . " />\n";
		}
		else {
			$output .= "\t<$el>" . encode($val) . "</$el>\n";
		}
	}

	#----------------------
	# <entry>
	#----------------------
	my $entries = $self->{entries};
	foreach my $entry (@{$entries}) {
		$output .= "<entry>\n";

		while(my ($el, $val) = each %{$entry}) {
			next unless ($feed->{$el});

			if($el eq 'link') {
			# <link rel="alternate" type="text/html" href="http://site/url/"/>
				$output .= qq(\t<$el rel="alternate" type="text/html" href=")
						 . encode($val) . " />\n";
			}
			else {
				$output .= "\t<$el>" . encode($val) . "</$el>\n";
			}
		}
		$output .= "</entry>\n";
	}

	$output .= "\t</feed>\n";

    return $output;
}


# $rss = $self->to_rss($base_rss);
#
# 	$rss : RNA::RSS module
sub to_rss
{
	my $self = shift;
	my $rss = shift;

	my $feed = $self->{feed};
	my $channel = $rss->{channel};
	$channel->{title} = $feed->{title} if($feed->{title});
	$channel->{link} = $feed->{link} if($feed->{link});
	$channel->{description} = $feed->{tagline} if($feed->{tagline});
	$channel->{dc}->{creator} = $feed->{author}->{name} if($feed->{author}->{name});
	$channel->{dc}->{date} = $feed->{modified} if($feed->{modified});
	$channel->{dc}->{date} ||= $feed->{issued};
	$channel->{dc}->{subject} = $feed->{dc}->{subject} if($feed->{dc}->{subject});

	#--------------------------------
	# <entry> s
	#--------------------------------
	my $items_ref = $rss->{items};
	foreach my $entry (@{$self->{entries}}) {
		my $item = {};
		my $title = $entry->{title} || &RNA::Atom::empty_value;
		
		$item->{title} = $title;
		$item->{link}  = $entry->{link};
		$item->{description} = $entry->{summary};
		$item->{content}->{encoded} = $entry->{content} if($entry->{content});

		$item->{dc} = {};
		$item->{dc}->{date} 
			= &to_w3cdtf($entry->{modified} || $entry->{issued});
		$item->{dc}->{creator} = $entry->{author}->{name} if($entry->{author}->{name});
		$item->{dc}->{subject} = $entry->{dc}->{subject} if($entry->{dc}->{subject});

		push(@{$items_ref}, $item);
	}

	return $rss;
}


sub add_entry {
	my $self = shift;
	my $hash_ref = {@_};

	push (@{$self->{entries}}, $hash_ref);
}


sub parsefile {
	my $self = shift;
	my $file = shift;
	open(IN, $file) || croak "Cannot open file $file : $!";
	my $str = "";
	while(my $s = <IN>){
		$str .= $s;
	}
	$self->parse($str);
}


# $self->parse($str)
#
sub parse {
	my $self = shift;
	$self->init((%$self));

	my $str = shift;
	my $handler = AtomParseHandler->new(Result => $self);
	my $parser = XML::SAX::PurePerl->new(Handler => $handler);

	# for the perl version less then 5.7.2
	$str =~ s/encoding=["'].+?['"]//s;

	$parser->parse_string($str);
}


sub save {
	my ($self,$file) = @_;
	open(OUT,">$file") || croak "Cannot open file $file for write: $!";
	print OUT $self->as_string;
	close OUT;
}

# $result = &RNA::Atom::encode ($text);
sub encode {
	my $text = shift;
	
    $text =~ s/</&lt;/g;
    $text =~ s/>/&gt;/g;
    $text =~ s/"/&quot;/g;

	return $text;
}


# Auto detect of date format and transformation to W3CDTF format
#
# $w3cdtf_date = &RNA::Atom::Feed::to_w3cdtf($unknown_date_format)
sub to_w3cdtf
{
	return RNA::Utils::transform_to_w3cdtf(shift);
}



#=============================================================================

package AtomParseHandler;

use strict;
use Carp;

sub new {
    my $class = shift;
    my %opts = @_;

	my $self = \%opts;
    bless $self, $class;

	$self->reset;
	return $self;
}

sub reset
{
	my $self = shift;
	$self->{feed} = {};
	$self->{entries} = [];

	$self->{ElementNameStack} = [];
	$self->{ElementStack} = [];
	$self->{CurrentMode} = '';  # 'feed', 'entry', 'content'

}


# $self->push_el_name(name=>$el, uri=>$ns_uri);
sub push_el_name
{
	my $self = shift;
	my %hash = @_;

	push(@{$self->{ElementNameStack}}, \%hash);
}

# $el = $self->pop_el_name;
#
#	$el->{name}, $el->{uri}
#
sub pop_el_name
{
	my $self = shift;
	return pop @{$self->{ElementNameStack}};
}


# $self->get_current_el_name;
sub get_current_el_name
{
	my $self = shift;
	my $stack = $self->{ElementNameStack};

	return scalar(@{$stack}) > 0 ? $stack->[-1]->{name} : undef;
}

# $self->get_2nd_el_name;
sub get_2nd_el_name
{
	my $self = shift;
	my $stack = $self->{ElementNameStack};

	return scalar(@{$stack}) > 0 ? $stack->[-2]->{name} : undef;
}

# $self->get_current_el_uri;
sub get_current_el_uri
{
	my $self = shift;
	my $stack = $self->{ElementNameStack};

	return scalar(@{$stack}) > 0 ? $stack->[-1]->{uri} : undef;
}


# $self->push_elment_ref($elment);
sub push_elment_ref
{
	my $self = shift;
	my $element = shift;	# reference or element_name

	push(@{$self->{ElementStack}}, $element);
}

# $elment = $self->pop_element_ref;
sub pop_element_ref
{
	my $self = shift;
	return pop @{$self->{ElementStack}};
}

# $elment_ref = $self->get_current_element_ref;
sub get_current_element_ref
{
	my $self = shift;
	return $self->{ElementStack}->[-1];
}


# $self->set_mode($mode);
sub set_mode
{
	my $self = shift;
	my $mode = shift;
	$self->{CurrentMode} = $mode;
}

sub get_mode
{
	my $self = shift;
	return $self->{CurrentMode};
}


#-------------------------------------------------
# Handlers
#-------------------------------------------------

# DocumentHandler
sub set_document_locator {
	my $self = shift;
# 	print "set_document_locator\n";
}

sub start_document {
	my $self = shift;
#    print "start_document\n";    
	$self->reset;
}

sub end_document {
	my $self = shift;
#    print "end_document\n";

	my $result = $self->{Result};
	$result->{feed} = $self->{feed};
	$result->{entries} = $self->{entries};
}

sub start_element {
	my $self = shift;
#    print "start_element\n";
	my $el = shift;
# eval {require Data::Dumper; print Data::Dumper::Dumper($el);};

	my $element_name = $el->{LocalName} || ($el->{Name}=~/:(\S+)/)[0];
	my $element_uri = $el->{NamespaceURI};
	my $parent_name = $self->get_current_el_name;
	# set current element name 
	$self->push_el_name(name=>$element_name, uri=>$element_uri);

	# set mode
	if($element_name eq 'feed' || $element_name eq 'entry' 
		|| $element_name eq 'content' ) 
	{
		$self->set_mode($element_name);
	}

	# element
	my $element = {};
	my $parent = $self->get_current_element_ref();
	if($self->get_mode eq 'feed') {
		if($element_name eq 'feed') {
		# <feed>
		}
		elsif($element_name eq 'author') {
		#  <author>
		#    <name>著者名</name>
		#    <url>http://homepage/url/</url>
		#    <email>mail@example.com</email>
		#  </author>
			$parent->{$element_name} = {};
		}
		elsif($parent_name eq 'author') {
		}
		elsif($element_name eq 'link') {
		# <link rel="alternate" type="text/html" href="http://site/url/"/>
			my $rel = $el->{Attributes}->{'{}rel'} 
					|| $el->{Attributes}->{'{' . $NAMESPACE . '}rel'} ;
			if($rel->{Value} eq 'alternate') {
				my $href = $el->{Attributes}->{'{}href'} 
					|| $el->{Attributes}->{'{' . $NAMESPACE . '}href'} ;
				$parent->{$element_name} = $href->{Value};
			}
		}
		else {
		# <feed><tag></tag></feed>
			$parent->{$element_name} = '';
		}
		$element = $parent->{$element_name};
	}
	elsif($self->get_mode eq 'entry') {
		if($element_name eq 'entry') {
		# <entry> element
			unless($self->{entries}) {
				$self->{entries} = [];
			}

			push(@{$self->{entries}}, $element);
		}
		elsif($element_name eq 'link') {
		# <link rel="alternate" type="text/html" href="http://site/url/"/>
			my $rel = $el->{Attributes}->{'{}rel'} 
					|| $el->{Attributes}->{'{' . $NAMESPACE . '}rel'} ;
			if($rel->{Value} eq 'alternate') {
				my $href = $el->{Attributes}->{'{}href'} 
					|| $el->{Attributes}->{'{' . $NAMESPACE . '}href'} ;
				$parent->{$element_name} = $href->{Value};
				$element = $parent->{$element_name};
			}
		}
		elsif($element_name eq 'author') {
		#  <author>
		#    <name>Auther Name</name>
		#    <url>http://homepage/url/</url>
		#    <email>mail@example.com</email>
		#  </author>
			$parent->{$element_name} = {};
			$element = $parent->{$element_name};
		}
		elsif($parent_name eq 'author') {
			$element = $parent->{$element_name};
		}
		else {
		# <entry><tag></tag></entry>
			$parent->{$element_name} = '';
			$element = $parent->{$element_name};
		}
	}
	elsif($self->get_mode eq 'content') {
		if($element_name eq 'content') {
		# <content><![CDATA[<p>記述</p>]]></content>
		# <content type="application/xhtml+xml"><p>記述</p></content>
			$self->{CurrentContent} = '';
		}
		else {
		# content の中の要素
			my $content = '<' . $el->{Name};
			foreach my $attr (values %{$el->{Attributes}}) {
				my $full_name = $attr->{Name};
				my $value = $attr->{Value};

				$content .= qq( $full_name="$value");
			}
			$content .= ' >';
			$self->{CurrentContent} .= $content;
		}
	}
	else {
	}

	# push stack
	if($self->get_mode eq 'feed') {
		$self->push_elment_ref($self->{feed});
	}
	elsif($self->get_mode eq 'entry') {
		$self->push_elment_ref($element);
	}
	else {
		$self->push_elment_ref($element);
	}

}

sub end_element {
    my $self = shift;
#    print "end_element\n";
	my $el = shift;
# eval {require Data::Dumper; print Data::Dumper::Dumper($el);};

	my $full_name = $el->{Name};

	# for <content>
	if($self->get_mode eq 'content') {
		if($full_name =~ /:??content$/) {
			$self->{entries}->[-1]->{content} = $self->{CurrentContent};
		}
		else {
			if($self->{CurrentContent} =~ /<$full_name[^<\/>]*>$/) {
				chop($self->{CurrentContent});
				$self->{CurrentContent} .= ' />';
			}
			else {
				$self->{CurrentContent} .= "</$full_name>";
			}
		}
	}

	# clear current element name 
	$self->pop_el_name;

	# clear mode
	if($full_name =~ /:??entry$/) {
		$self->set_mode('feed');
	}
	elsif($full_name eq /:??content$/) {
		$self->set_mode('entry');
	}
	elsif($full_name eq /:??feed$/) {
		$self->set_mode('');
	}

#	print $el->{Name} . ' : ' . $self->get_mode . "\n";
	# pop stack
	my $pop_el = $self->pop_element_ref;
}

sub characters {
    my $self = shift;
    my $node  = shift;
    my $str = $node->{Data}; 
#   print "Char: ", $node->{Data}, "\n";
#   print $self->get_mode . "\n";
#   print "characters\n";

	# <content>
	if($self->get_mode eq 'content') {
		if($str =~ /[\<\>]/) {
			$self->{CurrentContent} .= "<![CDATA[$str]]>";
		}
		else {
			$self->{CurrentContent} .= $str;
		}
	}

	if ($str =~ /^\s+$/) {
		return;
	}

	my $element_ns_uri = $self->get_current_el_uri;
	my $element_name = $self->get_current_el_name;
	my $parent_name = $self->get_2nd_el_name;
	my %prefix2uri_hash = reverse %{$modules};

#print STDERR "uri : $element_ns_uri\n";#
#print STDERR "name: $element_name\n";
#print STDERR "pname: $parent_name\n\n";

	unless($element_name) {
		return;
	}

	if($self->get_mode eq 'feed') {
		if($parent_name eq 'author') {
		# <author> <tab> </tab> </author>
			$self->{feed}->{author}->{$element_name} = $str;
		}
		else {
		# <feed><author></author></feed>
			$self->{feed}->{$element_name} = $str;
		}
	}
	elsif($self->get_mode eq 'entry') {
		if($parent_name eq 'author') {
			$self->{entries}->[-1]->{author}->{$element_name} = $str;
		}
		elsif($element_ns_uri eq $prefix2uri_hash{dc}) {
			$self->{entries}->[-1]->{dc}->{$element_name} = $str;
		}
		elsif($element_name ne 'entry') {
			$self->{entries}->[-1]->{$element_name} = $str;
		}
	}
	else{
	# 現在は何もなし
	}
}

sub processing_instruction {
    my $self = shift;
#    print "processing_instruction\n";
}

sub ignorable_whitespace {
    my $self = shift;
#    print "ignorable_whitespace\n";
}

# LexHandler
sub comment {
    my $self = shift;
#    print "comment\n";
}

# DTDHandler
sub notation_decl {
    my $self = shift;
#    print "notation_decl\n";
}

sub unparsed_entity_decl {
    my $self = shift;
#    print "entity_decl\n";
}

# EntityResolver
sub resolve_entity {
    my $self = shift;
#    print "resolve_entity\n";
    return '';
}




#=============================================================================
1;
__END__

■ Tips
start_element() に渡されるデータ形式
（<pre:el xml:lang="ja" atpre1:attr1="atval1"> の場合）
{
	'Prefix' => 'pre',
	'LocalName' => 'el',
	'Name' => 'feed',
	'NamespaceURI' => 'http://purl.org/atom/ns#',
	'Attributes' => {
		'{http://www.w3.org/XML/1998/namespace}lang' => {
			'Prefix' => 'xml',
			'LocalName' => 'lang',
			'Value' => 'ja',
			'Name' => 'xml:lang',
			'NamespaceURI' => 'http://www.w3.org/XML/1998/namespace'
		},
			'{http://sum/url#}attr1' => {
				'Prefix' => 'atpre1',
				'LocalName' => 'attr1',
				'Value' => 'atval1',
				'Name' => 'atpre1:attr1',
				'NamespaceURI' => 'http://sum/url#'
			},
		},
};



#============================================================================
# デバッガ
#============================================================================
#!/usr/bin/perl


use strict;


my $str = <<'__EEE__';
<?xml version="1.0" encoding="UTF-8"?>
<feed version="0.3"
  xmlns="http://purl.org/atom/ns#"
  xml:lang="ja">
  <title>サイト タイトル</title>
  <link rel="alternate" type="text/html" href="http://site/url/"/>
  <modified>2004-01-02T03:04:05Z</modified>
  <author>
    <name>著者名</name>
    <url>http://homepage/url/</url>
    <email>mail@example.com</email>
  </author>

  <tagline>記述</tagline>
  <id>tag:naoya.dyndns.org,2004:2</id>

  <entry>
    <title>タイトル１</title>
    <link rel="alternate" type="text/html" href="http://site/url/entry001.html"/>
    <modified>2004-01-02T03:04:05Z</modified>
    <issued>正式発表？の日</issued>
    <id>ID1</id>
    <summary type="text/plain">サマリー１...</summary>
    <content type="text/html" xml:lang="ja" mode="escaped" rel="fragment">
      <![CDATA[<p>エスケープされた<em>記述</em> &lt; </p>]]>
    </content>
  </entry>

  <entry>
    <title>タイトル２</title>
    <link rel="alternate" type="text/html" href="http://site/url/entry002.html"/>
    <modified>2004-02-03T05:06:07Z</modified>
    <issued>正式発表？の日</issued>
    <id>ID1</id>
    <summary type="text/plain">サマリー２...</summary>
    <content type="application/xhtml+xml">
     <xhtml:p xmlns:xhtml="http://www.w3.org/1999/xhtml"><xhtml:p>
       <xhtml:a xhtml:href="http://hogefuga/">インラインXMLによる</xhtml:a> 記述２
       <input type="button" />
     </xhtml:p></xhtml:p>
    </content>
  </entry>

</feed>
__EEE__


use lib qw(lib extlib);
use RNA::Atom::Feed;
use RNA::RSS;
use Data::Dumper;


my $atom = new RNA::Atom::Feed;
$atom->parse($str);

my $rss = new RNA::RSS;
$atom->to_rss($rss);
print $rss->as_string;

#print Dumper($atom);


