package RNA::Auth;
#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
# Authentication Module
# 　
#=============================================================================

use strict;
use Carp;
use RNA::Crypt::Blowfish;
use RNA::Crypt::NoCrypt;
use RNA::Utils;
use vars qw($VERSION);

$VERSION = '0.1';

my $default_encoding = 'UTF-8';
my $username_label = 'username';
my $passwd_label = 'passwd';
my $default_template = q(<html>
	<head>
		<title>RNA login</title>
		<meta http-equiv="Content-Type" content="text/html; charset=)
		. $default_encoding
		. q(" />
		<meta http-equiv="Content-Script-Type" content="text/javascript" />
		<script type="text/javascript">
		<!--
		function set_cookie(<$RNAUserNameLabel$>, <$RNAPasswdLabel$>) {
			document.cookie
				 = "<$RNAUserNameLabel$>=" + escape(<$RNAUserNameLabel$>) + "; ";
			//	+ "path=/home/username/public_html/rna/; ";
			document.cookie
				 = "<$RNAPasswdLabel$>=" + escape(<$RNAPasswdLabel$>) + "; ";
		}
		// -->
		</script>
	</head>

	<body bgcolor="#eeeeee" text="#bbbbbb">
		<h2>RNA Login</h2><br>

		<form method="post" action="<$RNATransferURI$>" onSubmit="set_cookie(this.<$RNAUserNameLabel$>.value, this.<$RNAPasswdLabel$>.value); return true;">
		<table>
		<tr><td><$RNAUserNameLabel$> :</td><td><input type="text" name="<$RNAUserNameLabel$>"></td></tr>
		<tr><td><$RNAPasswdLabel$> :</td><td><input type="password" name="<$RNAPasswdLabel$>"></td></tr>
		<tr><td><input type="submit" value="Login"></td></tr>
		</form>
	</body>
</html>
);

# $auth = new RNA::Auth(mode=>'file', keyfile=>'cache/key.dat', args=>{file=>'etc/.rna-passwd'});
# $auth = new RNA::Auth(mode=>'file', key=>'0A4D24c8', args=>{file=>'etc/.rna-passwd'});
# $auth = new RNA::Auth(mode=>'weblog', keyfile=>'cache/key.dat', args=>{uri=>$weblog_uri, blog_id=>$weblog_id, xmlrpc_uri=>$xmlrpc_uri});
sub new {
	my $class = shift;
	my $self = {};

	bless $self, $class;
    
	$self->init(@_);
	
	return $self;
}


sub init {
    my $self = shift;
    my %arg = @_;

	my $mode = $arg{mode}||'file';
	my $drivers_arg = $arg{args};
	
	# driver
	my $driver_name= 'RNA::Auth::'.ucfirst(lc($mode));
	my $exec_str = 
		"require $driver_name\;new $driver_name\(\%\{\$drivers_arg\}\)\;";
	$self->{_driver} = eval $exec_str;
	croak "Invalid Auth Driver : [$exec_str] ($@)" if($@);

	# cipher key
	my $key = $arg{key} || eval{&RNA::Utils::read_file($arg{keyfile});};
	chomp($key);
	$self->{_cipher} = $key ? 
	 	new RNA::Crypt::Blowfish(key=>$key) :
		new RNA::Crypt::NoCrypt;
}


# $bool = $self->check($username, $passwd, $is_encrypted);
sub check
{
	my $self = shift;
	my ($username, $passwd, $is_encrypted) = @_;
	$passwd = $self->decrypt($passwd) if($is_encrypted);
	
	return $self->{_driver}->check($username, $passwd);
}

# $bool = $self->add_user($username, $passwd, $is_encrypted);
sub add_user
{
	my $self = shift;
	my ($username, $passwd, $is_encrypted) = @_;
	$passwd = $self->decrypt($passwd) if($is_encrypted);

	return $self->{_driver}->add_user($username, $passwd);
}

# $bool = $self->update_user($username, $passwd, $is_encrypted);
sub update_user
{
	my $self = shift;
	my ($username, $passwd, $is_encrypted) = @_;
	$passwd = $self->decrypt($passwd) if($is_encrypted);

	return $self->{_driver}->update_user($username, $passwd);
}

# $bool = $self->delete_user($username);
sub delete_user
{
	my $self = shift;
	return $self->{_driver}->delete_user(@_);
}


# $label = &RNA::Auth::username_label;
sub username_label
{
	return $username_label;
}

# $label = &RNA::Auth::passwd_label;
sub passwd_label
{
	return $passwd_label;
}


#---------------------------------------------------------------------------
# Web
#---------------------------------------------------------------------------

# $bool = $self->check_cookie($cgi);
#
# passwd is encrypted
sub check_cookie
{
	my $self = shift;
	my $cgi = shift;

	my $username = $cgi->cookie($username_label);
	my $passwd = $cgi->cookie($passwd_label);

	return $self->check($username, $passwd, 1);
}


# $bool = $self->check_cookie($cgi, $is_encrypted);
#
sub check_param
{
	my $self = shift;
	my $cgi = shift;
	my $is_encrypted = shift;

	my $username = $cgi->param($username_label);
	my $passwd = $cgi->param($passwd_label);

	return $self->check($username, $passwd, $is_encrypted);
}


# $str = $self->login_page(transfer=>$uri, template=>$template, encoding=>'UTF-8');
sub login_page
{
	my $self = shift;
	my %hash = @_;

	my $template = $hash{template} || $default_template;
	my $transfer_uri = $hash{transfer};
	my $encoding = $hash{encoding} || $default_encoding;

	my %text_hash = (
		RNAUserNameLabel=>$username_label, RNAPasswdLabel=>$passwd_label, 
		RNATransferURI=>RNA::Utils::url_encode_minimal($transfer_uri), 
		RNAEncoding=>$encoding);

	foreach my $t (keys %text_hash){
		$template =~ s/<\$$t\$>/$text_hash{$t}/ges;
	}

	require CGI;
	my $header = CGI->new->header(-type=>'text/html', -charset => $encoding);

	return $header . $template;
}

# $cookie(array_ref) = $self->login_cookie($username, $passwd, $is_encrypted);
sub login_cookie
{
	my $self = shift;
	my ($username, $passwd, $is_encrypted) = @_;
	$passwd = $self->encrypt($passwd) unless($is_encrypted);

	# Cookie
	require CGI;
	my $cgi = new CGI;
	my $path = &cookie_path($cgi);
	my $cookie_u = $cgi->cookie(
		-name=>&username_label, -value=>$username, -path=>$path);
	my $cookie_p = $cgi->cookie(
		-name=>&passwd_label, -value=>$passwd, -path=>$path);

	return [$cookie_u, $cookie_p];
}

# $cookie(array_ref) = $self->logout_cookie;
sub logout_cookie
{
	my $self = shift;

	# Cookie
	require CGI;
	my $cgi = new CGI;
	my $path = &cookie_path($cgi);
	my $cookie_u = $cgi->cookie(-name=>&username_label, 
		-value=>'', -expires=>'-1d', -path=>$path);
	my $cookie_p = $cgi->cookie(-name=>&passwd_label, 
		-value=>'', -expires=>'-1d', -path=>$path);

	return [$cookie_u, $cookie_p];
}

# $path = &RNA::Auth::cookie_path($cgi);
sub cookie_path
{
	my $cgi = shift;
	
	my $path = $cgi->url(-absolute=>1);
	$path =~ s/\/[^\/]*?$//;
	return $path;
}

#---------------------------------------------------------------------------
# Encryption, Decryption
#---------------------------------------------------------------------------

# $ciphertext = $self->encrypt($plaintext);
sub encrypt
{
	my $self = shift;
	my $plaintext = shift;

	return $self->{_cipher}->encrypt($plaintext);
}

# $plaintext = $self->decrypt($ciphertext);
sub decrypt
{
	my $self = shift;
	my $ciphertext = shift;

	return $self->{_cipher}->decrypt($ciphertext);
}


#=============================================================================
1;
__END__

