package RNA::Auth::Weblog;
#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
# Authentication Module (for Weblog)
#=============================================================================

use strict;
use CGI::Carp;
use Net::Blogger;
use RNA;
use RNA::Utils;
use RNA::AutoDiscovery;
use RNA::RSD;

use vars qw($VERSION);

$VERSION = '0.1';

# $auth = new RNA::Auth::Weblog(xmlrpc_uri=>'http://***/mt-xmlrpc.cgi', blog_id=>4);
# $auth = new RNA::Auth::Weblog(uri=>'http://anweblog/index.html', blog_id=>4);
sub new {
	my $class = shift;
	my $self = {};
	
	bless $self, $class;
	
	$self->init(@_);
	
	return $self;
}


sub init {
	my $self = shift;
	my %hash = @_;

	$self->_reset;

	$hash{xmlrpc_uri} || $hash{uri} || 
		croak "<XMLRPC server's URI> or <Weblog toppage URI> is required.";

	$self->{_xmlrpc_uri} = $hash{xmlrpc_uri};
	$self->{_uri}        = $hash{uri};
	$self->{_blog_id}    = $hash{blog_id};

	unless($self->{_xmlrpc_uri} || $self->discover_xmlrpc) {
		die "Auto-Discovery of XMLRPC server is failed.\n";
	} 
}

# $self->discover_xmlrpc;
sub discover_xmlrpc
{
	my $self = shift;

	my $uri = $self->{_uri};

	my ($str, $headers) = &RNA::Utils::get_html(uri=>$uri, ua=>$RNA::NAME);
	my $link = RNA::AutoDiscovery->new(html=>$str)->search('title', 'RSD');
	my $rsd_uri = $link->{href};

	($str, $headers) = &RNA::Utils::get_html(uri=>$rsd_uri, ua=>$RNA::NAME);
	my $rsd = new RNA::RSD;

	eval{$rsd->parse($str);};

	foreach my $api (@{$rsd->apis}) {
		if(lc($api->{name}) =~ /^metaweblog|blogger$/) {
			$self->{_xmlrpc_uri} = $api->{apiLink};
			return 1;
		}
	}

	return 0;

}


# $self->_reset
sub _reset
{
	my $self = shift;
}


# $bool = $self->check($username, $passwd);
sub check
{
	my $self = shift;
	my ($username, $passwd) = @_;

	my $mt = Net::Blogger->new(engine=>"movabletype");
	$mt->Proxy($self->{_xmlrpc_uri});
	$mt->Username($username);
	$mt->Password($passwd);
	$mt->BlogId($self->{_blog_id});

	my $metaweblog = $mt->metaWeblog();

	return $mt->mt()->getCategoryList()||$metaweblog->getCategories() ? 1 : 0;
}

# $bool = $self->add_user($username, $passwd);
sub add_user
{
	my $self = shift;
	my ($username, $passwd) = @_;

	return 0;
}

# $bool = $self->update_user($username, $passwd);
sub update_user
{
	my $self = shift;
	my ($username, $passwd) = @_;

	return 0;
}

# $bool = $self->delete_user($username);
sub delete_user
{
	my $self = shift;
	my ($username) = @_;

	return 0;
}



#=============================================================================
1;
__END__


#!/usr/bin/perl

use strict;
use lib qw(lib extlib);

use RNA::Auth::Weblog;

my $auth = new RNA::Auth::Weblog(xmlrpc_uri=>'http://www.semblog.org/mt/mt-xmlrpc.cgi', blog_id=>4);

print $auth->check('', '') ? 'success' : 'fail';
