#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
# Base API for XML-RPC 
#
#  !! Do not  'use' or 'require' the modules that access STDIN such as 'CGI.pm'
#	【注意】標準入力にアクセスするような処理を行わないこと
#
#==============================================================================


package RNA::BaseAPI;
use strict;
use Carp;

use vars qw($VERSION $ALL_CATEGORY $CONFIG_FILE);

$VERSION = '0.1';

my $CONFIG_FILE = ''; # './config.pl'

$ALL_CATEGORY = '__ALL__';

#-------------------------
# Fault list
#-------------------------
my %fault_list = (
	# common 2000
	Unauthorized => {
		code => 2101,
		string => 'Can not verify that you are authorized.'
	},
	InternalAuthError => {
		code => 2102,
		string => 'A program error occured during authentication.'
	},
	Interval => {
		code => 2201,
		string => 'This operation can be executed at predetermined intervals.'
	},

	# Site 3200
	SiteList => {
		code => 3201,
		string => 'Can\'t open the site list.'
	},
	ExistingSiteURI => {
		code => 3205,
		string => 'Can\'t be added. The URI is already in the site list.'
	},

	# Recent Site or/and Entry List 3300

	# Clip 3500
	ClipList => {
		code => 3501,
		string => 'Can\'t open the clip list.'
	},
	ClipTemplate => {
		code => 3502,
		string => 'Can\'t open the clip template.'
	},
	ExistingClipURI => {
		code => 3505,
		string => 'Can\'t be added. The URI is already in the clip list.'
	},

	# ReadHistory 4100
	ReadHistory => {
		code => 4101,
		string =>'Can\'t open the read-history. Please check it\'s permission.'
	},
);
my $latest_fault = {}; # {code =>111, string=>'aaa'}
my $default_fault = {code => 2001, string=>'RNA Error'};

#-----------------------------------------
# fault 関連
#-----------------------------------------

# return &_fault($ID);
sub _fault
{
	my $id = shift;
	$latest_fault = (
		exists $fault_list{$id} ? $fault_list{$id} : $default_fault);
	
	return undef;
}

# $info = &RNA::BaseAPI::get_fault_info;
# 	$info : {code =>111, string=>'aaa'}
sub get_fault_info
{
	return $latest_fault;
}

#-----------------------------------------
# Config 関連
#-----------------------------------------

# &RNA::BaseAPI::config_file($filename);
sub config_file
{
	return (@_ ? $CONFIG_FILE = shift : $CONFIG_FILE); 
}

# $rna = RNA::BaseAPI::load_module;
sub load_module
{
	require RNA;
	require RNA::Utils;
	require RNA::RSS;
	require RNA::RSS::WebEdit;
	require RNA::AntennaTree;

	return RNA->new(Config => $CONFIG_FILE);
}

#-----------------------------------------
# Authentication
#-----------------------------------------

# $bool = &_auth($rna, $username, $passwd);
sub _auth
{
	my ($rna, $username, $passwd) = @_;

	my $auth = eval{$rna->get_auth;};
	return &_fault('InternalAuthError') if($@);

	return $auth->check($username, $passwd);
}

#=============================================================================
# method
#=============================================================================

# $ret = &RNA::BaseAPI::refresh;
sub refresh
{
	my $rna = &load_module;
	my $config = $rna->{Config};

	eval{$rna->update;};
	if($@) {
	# Error
		return &_fault('Interval');
	}

	return 1;
}


# $v = &RNA::BaseAPI::getVersion;
sub getVersion
{
	my $rna = &load_module;
	my $config = $rna->{Config};

	return $rna->{VERSION};
}


# my $ret = &RNA::BaseAPI::addClip({username=>$username, passwd=>$passwd, title=>$title, link=>'http://***/', description=>'***', subject=>'category', creator=>'fuga', date=>'2001-01-01', source=>'source', sourceURL=>'http://***/'});
# 		$ret == 1 : normal end
#		$ret == undef : fault
#
sub addClip
{
	my $rna = &load_module;
	my $config = $rna->{Config};
	my $clip_rss_file = $config->{ClipList}->{RSS};

	my $arg_ref = shift;
	my %arg = %{$arg_ref};
	$arg{action} = 'Add';
	$arg{select} = $arg{link};

	#----------------------------
	# 認証
	#----------------------------
	if($config->{Authentication}->{ClipCGI}) {
		unless( _auth($rna, $arg{username}, $arg{passwd}) ) {
			return &_fault('Unauthorized');
		}
	}

	foreach my $k (keys %arg) {
		RNA::Utils::convert_char_code(\$arg{$k});	# UTF-8 に変換
	}

	# リストの取り出し
	my $rss = new RNA::RSS;
	eval {$rss->parsefile($clip_rss_file);};
	return &_fault('ClipList') if($@);

	my $err_msg = &RNA::RSS::WebEdit::update_rss($rss, \%arg, 'front');
	if($err_msg) {
	# Error
		return &_fault('ExistingClipURI');
	}
	else {
	# print file
		my $str = $rss->as_string;
		eval {&RNA::Utils::print_file($clip_rss_file, \$str); };
		return _fault('ClipList') if($@);

		my $template = 
			eval{RNA::Utils::read_file($config->{Template}->{ClipList}) };
		return _fault('ClipTemplate') if($@);
		
		my $str_ref = RNA::AntennaTree::apply_template_to_rss($rss, 
			$template, $config->{Template}->{Element});

		eval{RNA::Utils::print_file($config->{ClipList}->{HTML}, $str_ref);};
		return _fault('ClipList') if($@);

		return 1;
	}
}


# my $bool = &RNA::BaseAPI::addSite({title=>$title, link=>'http://***/', description=>'***', subject=>'category', creator=>'fuga'});
# 		$bool == 1 : normal end
#		$bool == undef : fault
#
sub addSite
{
	my $rna = &load_module;
	my $config = $rna->{Config};
	my $site_list_file = $config->{SiteList}->{File};

	my $arg_ref = shift;	# arguments
	my %arg = %{$arg_ref};
	$arg{action} = 'Add';
	$arg{select} = $arg{link};

	#----------------------------
	# 認証
	#----------------------------
	if($config->{Authentication}->{ConfigureCGI}) {
		unless( _auth($rna, $arg{username}, $arg{passwd}) ) {
			return &_fault('Unauthorized');
		}
	}

	foreach my $k (keys %arg) {
		RNA::Utils::convert_char_code(\$arg{$k});	# UTF-8 に変換
	}

	# リストの取り出し
	my $rss = new RNA::RSS;
	eval { $rss->parsefile($site_list_file); };
	return &_fault('SiteList') if($@);

	my $err_msg = &RNA::RSS::WebEdit::update_rss($rss, \%arg, 'back');
	# delete <ag:***>
	foreach my $item (@{$rss->{items}}) {
		delete $item->{ag};
	}

	if($err_msg) {
	# Error
		return &_fault('ExistingSiteURI');
	}
	else {
	# print file
		my $str = $rss->as_string;
		eval{ &RNA::Utils::print_file($site_list_file, \$str); };
		return &_fault('SiteList') if($@);

		return 1;
	}

	return 1;
}


# $list_ref = &RNA::BaseAPI::getSitesInCategory($category);
#
# 	$list_ref == [{title=>$title, link=>'http://***/', description=>'***', subject=>'$category', creator=>'fuga'}, {}, {}, ...] : normal end
#	$list_ref == undef : fault
#
sub getSitesInCategory
{
	my $target_category = shift;
	my $rna = &load_module;
	my $config = $rna->{Config};
	my $site_list_file = $config->{SiteList}->{File};

	my $rss = new RNA::RSS;
	eval {$rss->parsefile($site_list_file)};
	return &_fault('SiteList') if ($@);

	my $all_flag = $ALL_CATEGORY;
	my $ret = [];
	foreach my $item (@{$rss->{items}}) {
		if($target_category eq $all_flag 
			|| $target_category eq $item->{dc}->{subject})
		{
			my $site = {
				title => $item->{title}||'',
				link  => $item->{link}||'',
				description => $item->{description}||'',
				subject  => $item->{dc}->{subject}||'',
				creator  => $item->{dc}->{creator}||''
			};

			push (@{$ret}, $site);
		}
	}

	return $ret
}


# $array_ref = &RNA::BaseAPI::getSiteCategories;
sub getSiteCategories
{
	my $rna = &load_module;
	my $config = $rna->{Config};
	my $site_list_file = $config->{SiteList}->{File};

	my $rss = new RNA::RSS;
	eval {$rss->parsefile($site_list_file)};
	return &_fault('SiteList') if ($@);

	my %list = ();
	foreach my $item (@{$rss->{items}}) {
		unless($config->is_empty_content($item->{dc}->{subject})) {
			$list{$item->{dc}->{subject}}++;
		}
	}
	delete $list{$config->{HatenaFlag}};

	return \%list;
}


# my $bool = &RNA::BaseAPI::postReadHistory($account_ref, $pages_ref);
# 		$account_ref = {username=>'username', passwd=>'passwd'};
# 		$pages_ref = [
#			{link=>'http://***/', date=>'***', option=>'***'},
#			{link=>'http://***/', date=>'***', option=>'***'},
#		];
#
# 		$bool == 1 : normal end
#		$bool == undef : fault
#
sub postReadHistory
{
	my $rna = &load_module;
	my $config = $rna->{Config};
	my $read_history_file = $config->{ReadHistory}->{RSS};

	my ($account_ref, $pages_ref) = @_;	# arguments

	#----------------------------
	# Authentication
	#----------------------------
	#if($config->{Authentication}->{ConfigureCGI}) {
		unless(_auth($rna, $account_ref->{username}, $account_ref->{passwd})) {
			return &_fault('Unauthorized');
		}
	#}

	foreach my $p (@{$pages_ref}) {
		foreach my $k (keys %{$p}) {
			RNA::Utils::convert_char_code(\($p->{$k}));	# UTF-8
		}
	}

	# read history (rss)
	my $rss = new RNA::RSS;
	eval { $rss->parsefile($read_history_file); };
	return &_fault('ReadHistory') if($@);
	&RNA::Utils::set_rss($rss, 
		$config->{ReadHistory}->{Title}, 
		$config->{BaseURI} . $config->{ReadHistory}->{RSS}, 
		$config->{ReadHistory}->{Description}, 
		$rna->{Date}, $config->{Owner}, $config->{Language});

	#--------------------------------------------
	# update read history
	#--------------------------------------------

	# add
	foreach my $p (@{$pages_ref}) {
		$rss->add_item(
			title => $p->{title}||$config->empty_value,
			link  => $p->{link},
			dc    => {date => $p->{date}||''},
			semblog => {option => $p->{option}||''}
		);
	}

	$rss->sort;

	# delete duplicate items
	{
		my %h = ();
		my @a = grep(!$h{$_->{link} . '::' . $_->{semblog}->{option}}++, 
					@{$rss->{items}} );
		$rss->{items} = \@a;
	}

	# delete expired items
	{
		require HTTP::Date;
		my $now = HTTP::Date::str2time($rna->{Date})||0;  # [sec]
		my $term = $config->{ReadHistory}->{Term} * 24 * 60 * 60; # [sec]
		my $th = $now - $term - 1; # [sec]

		my @a = grep 
			{HTTP::Date::str2time($_->{dc}->{date}) > $th} @{$rss->{items}};
		$rss->{items} = \@a;
	}

	# print file
	my $str = $rss->as_string;
	eval{ &RNA::Utils::print_file($read_history_file, \$str); };
	return &_fault('ReadHistory') if($@);

	return 1;
}


# $list_ref = &RNA::BaseAPI::getReadHistory({username=>$username, passwd=>$passwd, date=>'2001-01-01'});
#
# 	$list_ref == [{link=>'http://***/', date=>'**'}, {}, {}, ...] : normal end
#     (first item is RNA information)
#	$list_ref == undef : fault
#
sub getReadHistory
{
	my $arg_ref = shift;	# arguments
	my %arg = %{$arg_ref};

	my $rna = &load_module;
	my $config = $rna->{Config};

	my $rss = new RNA::RSS;
	eval {$rss->parsefile($config->{ReadHistory}->{RSS})};
	return &_fault('ReadHistory') if ($@);

	require CGI;
	my $ret = [{
		title => 'RNA ' . $rna->{VERSION} . ' XML-RPC Server',
		link  => CGI->new->url(),
		date  => $rss->{channel}->{dc}->{date}
	}];

	require HTTP::Date;
	my $border_time = HTTP::Date::str2time($arg{date})||0;
	foreach my $item (@{$rss->{items}}) {
		last if(HTTP::Date::str2time($item->{dc}->{date}) < $border_time);

		my $ret_item = {
			link  => $item->{link}||'',
			date  => $item->{dc}->{date}||'',
			option  => $item->{semblog}->{option}||'',
		};

		push (@{$ret}, $ret_item);
	}

	return $ret
}



#=============================================================================
1;

