#=============================================================================
# Blowfish encryption 
#=============================================================================
# Copyright (C) 2003,2004	Ikki Ohmukai,		All rights reserved.
#
#
# This file is part of RNA.
#
#	RNA is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	RNA is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with RNA; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#=============================================================================
package RNA::Crypt::Blowfish;

use strict;
use Carp;
use Crypt::Blowfish_PP;
use vars qw($VERSION);

$VERSION = '0.1';

my $BLOCK_SIZE = 8; #[bytes]

# key は、32bit から 448bit 　まで
my $MIN_KEY_SIZE = 4;
my $MAX_KEY_SIZE = 56;
my $DEFAULT_KEY_SIZE = $MAX_KEY_SIZE; #[bytes]


# $crypt = new RNA::Crypt::Blowfish(key=>$key);
#    or
# $crypt = new RNA::Crypt::Blowfish(key_size=>50);
#
# $crypt = new RNA::Crypt::Blowfish;  # max key-size
# 
sub new 
{
	my $class = shift;
	my $self = {};

	bless $self, $class;
    
	$self->init(@_);
    
	return $self;
}


sub init {
    my $self = shift;
    my %hash = @_;

	$hash{key_size} ||= $DEFAULT_KEY_SIZE;

	$hash{key} 
		? $self->key($hash{key}) 
		: $self->key(generate_key($hash{key_size}));
}

# $self->key($key);
# my $key = $self->key;
sub key {
    my $self = shift;
	my $key  = shift;

	if($key) {

		# key format check
		unless($key =~ /^[a-f0-9]+$/i 
			&& length($key) >= $MIN_KEY_SIZE*2 
			&& length($key) <=  $MAX_KEY_SIZE*2)
		{
			croak "Invalid Key Format : $key";
		}
		
		return $self->{_key} = $key;
	}
	else {
		return $self->{_key};
	}
}


# my $key = RNA::Crypt::Blowfish::generate_key($key_size);
#
sub generate_key
{
	shift if UNIVERSAL::isa($_[0] => __PACKAGE__);
	my $key_size = shift;
	if($key_size < $MIN_KEY_SIZE || $key_size > $MAX_KEY_SIZE) {
		croak "Invalid key size : $MIN_KEY_SIZE <= $key_size <= $MAX_KEY_SIZE";
	}

	my @hex_alpha = ('A'..'F', 0..9);
	# Hex presentation
	my $key 
		= join('', map $hex_alpha[rand(scalar(@hex_alpha))], (1..$key_size*2));

	return $key;
}



# my $crypted_text = $self->encrypt($text);
sub encrypt
{
    my $self = shift;
	my $key  = $self->key;
	my $text = shift;

	# empty text
	return $text unless($text);

	my $real_key = pack("H*" , $key);

	my $cipher = new Crypt::Blowfish_PP($real_key);
	my @blocks = ($text=~/(.{1,$BLOCK_SIZE})/gos);

	print "Block:\t";
	map { print $_ . ' ' } @blocks;
	print "\n";

	# padding
	if(length($blocks[-1]) < $BLOCK_SIZE) {
		$blocks[-1] = pad_null($blocks[-1], $BLOCK_SIZE);
	}

	return unpack("H*", join('', map $cipher->encrypt($_), @blocks) );
}

# my $text = $self->decrypt($cryptedtext);
sub decrypt
{
	my $self = shift;
	my $text = shift;

	# empty text
	return $text unless($text);


	my $key  = $self->key;
	my $real_key = pack("H*" , $key);

	my $real_text = pack("H*", $text);

	my $BLOCK_SIZE = 8; #[bytes]
	my $cipher = new Crypt::Blowfish_PP($real_key);
	my @blocks = ($real_text=~/(.{1,$BLOCK_SIZE})/ogs);

	my @decrypted_blocks = map $cipher->decrypt($_), @blocks;

	# remove_padding
	$decrypted_blocks[-1] = remove_padding($decrypted_blocks[-1]);

	return join('', @decrypted_blocks);
}


# $padded_block = RNA::Crypt::Blowfish::pad_null($block, $BLOCK_SIZE);
sub pad_null
{
	shift if UNIVERSAL::isa($_[0] => __PACKAGE__);
	my ($block, $size) = @_;
	
	return $block . pack("C*", (0) x ($size - length($block) % $size));
}


# $str = remove_padding($block);
sub remove_padding
{
	shift if UNIVERSAL::isa($_[0] => __PACKAGE__);
	my ($block) = @_;

	$block=~ s/\0*$//s;
	return $block;
}

#==============================================================================
1;
