package RNA::FOAF;
#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
# 　FOAFを利用するためのモジュール
#=============================================================================

use strict;
use CGI::Carp;
use RNA::FOAF::Person;
use XML::Parser::Lite;
use vars qw($VERSION $modules $NAMESPACE);

my $build_date = join('', ('$Date: 2004/03/13 15:59:56 $' =~ /\d{2}(\d{2})\/(\d{2})\/(\d{2})/));
$VERSION = $build_date;

$NAMESPACE = 'http://xmlns.com/foaf/0.1/';
my $PREFIX = 'foaf';
my $DEFAULT_ENCODING = 'UTF-8';

my %foaf_field = {
	encoding => $DEFAULT_ENCODING,
	person   => {}, # RNA::FOAD::Person
	_work    => {
		el_stack => [],
		person_stack => [],
		ns_map => {prefix=>'uri'}
	}
};

my $modules = {
	$NAMESPACE => $PREFIX,
	'http://www.w3.org/1999/02/22-rdf-syntax-ns#' => 'rdf',
	'http://www.w3.org/2000/01/rdf-schema#'       => 'rdfs',
	'http://xmlns.com/wot/0.1/'                   => 'wot',
	'http://purl.org/dc/elements/1.1/'            => 'dc',
	'http://www.semblog.org/ns/semblog/0.1/'      => 'semblog',
};

my %rdf_resource_fields = (
	$NAMESPACE =>  {
		'mbox'     => 1,
		homepage   => 1,
		interest   => 1,
		topic_interest => 1,
		depiction  => 1,
		depicts => 1,
		img        => 1,
		thumbnail  => 1,
		phone      => 1,
		workplaceHomepage => 1,
		workInfoHomepage  => 1,
		schoolHomepage    => 1,
		weblog     => 1,
		publications => 1,
		made  => 1,
		currentProject => 1,
		pastProject => 1,
		page => 1,
		topic => 1,
		theme => 1,
		linkedWith => 1,
		fundedBy => 1,
		maker => 1,
		logo => 1,
		accountServiceHomepage => 1,
		member => 1,
	},
	'http://www.w3.org/2000/01/rdf-schema#'	=> {
		'seeAlso'	=> 1
	},
	'http://xmlns.com/wot/0.1/'  => {
		'assurance' => 1
	},
	'http://www.semblog.org/ns/semblog/0.1/' => {
		'rna'    => 1,
		'foaftb' => 1
	}
);

sub new {
	my $class = shift;
	my $self = {};

	bless $self, $class;
	$self->init(@_);
	
	return $self;
}


sub init {
	my $self = shift;
	my %hash = @_;

	# initialize items
	$self->{person} = new RNA::FOAF::Person;

	# modules
	$self->{modules} = $modules;

	# encoding
	if (exists($hash{encoding})) {
		$self->{encoding} = $hash{encoding};
	}
	else {
		$self->{encoding} = $DEFAULT_ENCODING;
	}
}

sub person {
	my $self = shift;

	if(@_) {
		$self->{person} = new RNA::FOAF::Person(@_);
	}

	return $self->{person};
}


# $self->add_module(prefix=>'aaa', uri=>'http://hogehoge/');
sub add_module {
	my $self = shift;
	my $hash = {@_};

    $hash->{prefix} || croak "a prefix should not be null\n";
	$hash->{uri} || croak "a URI required in a namespace declaration\n";

	$self->{modules}->{$hash->{uri}} = $hash->{prefix};
}


#----------------------------------------------------------------------------
# 出力
#----------------------------------------------------------------------------

# $self->as_string
sub as_string
{
	my $self = shift;

	my $rdf 
		= $self->{modules}->{'http://www.w3.org/1999/02/22-rdf-syntax-ns#'};

	# XML 宣言
	my $output = qq(<?xml version="1.0" encoding=") . $self->{encoding} 
		. qq("?>) ."\n\n";

	# <rdf:RDF>
	$output .= "<$rdf:RDF\n";
	while (my($k, $v) = each %{$self->{modules}}) {
		$output .= " xmlns:$v=\"$k\"\n";
	}
	$output .= ">\n\n";
	
	$output .= $self->as_string_person($self->person);
	
	$output .= "</$rdf:RDF>\n";
}


# $self->as_string_person($person);
sub as_string_person
{
	my $self = shift;
	my $person = shift;

	my $rdf 
		= $self->{modules}->{'http://www.w3.org/1999/02/22-rdf-syntax-ns#'};
	my $foaf = $self->{modules}->{$NAMESPACE};
	my $rdfs = $self->{modules}->{'http://www.w3.org/2000/01/rdf-schema#'};
	my $wot =  $self->{modules}->{'http://xmlns.com/wot/0.1/'};
	my $dc = $self->{modules}->{'http://purl.org/dc/elements/1.1/'};
	my $semblog = $self->{modules}->{'http://www.semblog.org/ns/semblog/0.1/'};
	my @prefixes = values %{$self->{modules}};
	
	my $output = "<$foaf:Person>\n";

	# <foaf:***>
	while(my($el, $val) = each %{$person}) {
		next unless($val);
		next if(ref $val);
		
		if(exists $rdf_resource_fields{$NAMESPACE}->{$el}) {
			$output .= qq(<$foaf:$el $rdf:resource=") 
				. encode($val) . qq(" />\n);
		}
		else {
			$output .= "<$foaf:$el>".  encode($val) ."</$foaf:$el>\n";
		}
	}

	# each module
	while ( my($uri, $prefix) = each %{$self->{modules}} ) {
		# <foaf:***>
		next if ($prefix eq $PREFIX);

		while (my($el, $val) = each %{$person->{$prefix}}) {
			## skip <rdfs:seeAlso>
			#next if($prefix eq $rdfs && $el eq 'seeAlso');

			if ($rdf_resource_fields{$uri} 
				&& exists $rdf_resource_fields{$uri}->{$el})
			{
				$output .= qq(<$prefix:$el $rdf:resource=") 
							. encode($val) . qq(" />\n);
			}
			else {
				$output .= "<$prefix:$el>".  encode($val)."</$prefix:$el>\n";
			}
		}
  	}

	# <foaf:knows>
	foreach my $friend (@{$person->knows}) {
		$output .= "\n<$foaf:knows>\n" . $self->as_string_person($friend)
			. "</$foaf:knows>\n\n";
	}

	$output .= "</$foaf:Person>\n";
}


# $str = encode($str);
sub encode
{
	my ($t) = @_;
	my %cv = ('"' => '&quot;', '<' => '&lt;',  '>' => '&gt;');
	$t =~ s/([<>"])/$cv{$1}||$1/ge;
	$t;
}



#----------------------------------------------------------------------------
# パーサー関連
#----------------------------------------------------------------------------

# $self->parse($str)
sub parse {
	my $self = shift;
	$self->init((%{$self}));

	my $parser = new XML::Parser::Lite;
	$parser->setHandlers(
		Init    => eval 'sub {shift; $self->handle_init(@_)}',
		Final   => eval 'sub {shift; $self->handle_final(@_)}',
		Char    => eval 'sub {shift; $self->handle_char(@_)}',
		Start   => eval 'sub {shift; $self->handle_start(@_)}',
		End     => eval 'sub {shift; $self->handle_end(@_)}'
	);

	$parser->parse(shift);
}

sub parsefile {
	my $self = shift;
	my $file = shift;
	open(IN, $file) || croak "Cannot open file $file : $!";
	my $str = join('', <IN>);
	$self->parse($str);
}


sub reset_parse
{
	my $self = shift;

	$self->{_work} = {};
	my $work = $self->{_work};
	$work->{person_stack} = [];
	$work->{el_stack} = [];
	$work->{ns_map} = {};
}

# $self->push_el(name=>$el, uri=>$ns_uri);
sub push_el
{
	my $self = shift;
	my %hash = @_;

	push(@{$self->{_work}->{el_stack}}, \%hash);
}

# $el = $self->pop_el;
#
#	$el->{name}, $el->{uri}
#
sub pop_el
{
	my $self = shift;
	return pop @{$self->{_work}->{el_stack}};
}


# $self->get_current_el_name;
sub get_current_el_name
{
	my $self = shift;
	my $stack = $self->{_work}->{el_stack};

	return scalar(@{$stack}) > 0 ? $stack->[-1]->{name} : undef;
}

# $self->get_current_el_uri;
sub get_current_el_uri
{
	my $self = shift;
	my $stack = $self->{_work}->{el_stack};

	return scalar(@{$stack}) > 0 ? $stack->[-1]->{uri} : undef;
}


# $self->push_person($person);
sub push_person
{
	my $self = shift;
	my $element = shift;	# reference or element_name

	push(@{$self->{_work}->{person_stack}}, $element);
}

# $person = $self->pop_person;
sub pop_person
{
	my $self = shift;
	return pop @{$self->{_work}->{person_stack}};
}

# $person = $self->get_current_person;
sub get_current_person
{
	my $self = shift;
	my $stack = $self->{_work}->{person_stack};
	return scalar(@{$stack}) > 0 ? $stack->[-1] : undef;
}

# $self->add_ns_map(uri=>'uri', prefix=>'prefix');
sub add_ns_map
{
	my $self = shift;
	my %hash = @_;

	$hash{prefix} || croak "prefix required\n";
    $hash{uri} || croak "a URI required in a namespace declaration\n";

	$self->{_work}->{ns_map}->{$hash{prefix}} = $hash{uri};
}

# $uri = $self->target_prefix2uri($prefix);
sub target_prefix2uri
{
	my ($self, $prefix) = @_;
	return $self->{_work}->{ns_map}->{$prefix};
}

# $prefix = $self->uri2prefix($uri);
sub uri2prefix
{
	my ($self, $uri) = @_;
	return $self->{modules}->{$uri};
}

#------------------------
# ハンドラ
#------------------------
sub handle_init
{
	my $self = shift;

#	print "init: \n";

	$self->{person} = {};
	$self->reset_parse;
}

sub handle_final
{
	my $self = shift;

#	print "final\n";
}

sub handle_char {
	my ($self, $cdata) = (@_);
#	print "char: $cdata\n";

	my $el_name = $self->get_current_el_name;
	my $person = $self->get_current_person;
	my $ns_uri = $self->get_current_el_uri;

	my %exclude = ('knows'=>1, 'Person'=>1);

	return if($exclude{$el_name});

	if($person) {
		if($ns_uri && $ns_uri ne $NAMESPACE) {
			$person->{$self->uri2prefix($ns_uri)}->{$el_name} ||= $cdata;
		}
		else {
			$person->{$el_name} ||= $cdata;
		}
	}
}

sub handle_start {
	my $self = shift;
	my $el   = shift;
	my %attr = @_;

#	print "start: $el (" . join(',', %attr) . ")\n";
	my $parent_el_name = $self->get_current_el_name;

	#----------------------------------
	# element
	#----------------------------------
	my ($prefix, $el_name) = split(':', $el);
	unless($el_name) {
		$el_name = $prefix;
		$prefix = '';
	}

	$self->push_el(name=>$el_name, uri=>$self->target_prefix2uri($prefix));
	my $ns_uri = $self->target_prefix2uri($prefix);
	$prefix = $self->uri2prefix($ns_uri);

	if($el_name eq 'Person') {
		my $person = new RNA::FOAF::Person;

		if($parent_el_name eq 'knows') {
			my $cur_person = $self->get_current_person;
			if($cur_person){
				$cur_person->{knows} || ($cur_person->{knows} = []);
				push (@{$cur_person->{knows}}, $person);
			}
			else{
				croak "invalid foaf (element: $el)\n";
			}
		}
		else {
			$self->{person} = $person;
		}

		$self->push_person($person);
	}
	my $person = $self->get_current_person;

	#----------------------------------
	# attributes
	#----------------------------------

	# separate 'xmlns:' and other attribute
	my %xmlns = ();
	my %other_attr = ();
	while( my($nm, $val) = each %attr) {
		if (substr($nm, 0, 5)  eq 'xmlns') {
			$xmlns{$nm} = $val;
		}
		else {
			$other_attr{$nm} = $val;
		}
	}
	
	# namespace mapping
	while( my($nm, $val) = each %xmlns) {
		my $attpre = length($nm) > 5 ? substr($nm, 6) : $PREFIX;
		$self->add_ns_map(uri=>$val, prefix=>$attpre);
		unless (exists $self->{modules}->{$val}) {
			$self->add_module(uri=>$val, prefix=>$attpre);
		}
	}

	# other attributes
	while( my($nm, $val) = each %other_attr) {
		my ($attpre, $attname) = split(':', $nm);
		unless($attname) {
			$attname = $attpre;
			$attpre = '';
		}
		my $att_ns_uri = $self->target_prefix2uri($attpre);
		$attpre = $self->uri2prefix($att_ns_uri);

		if($rdf_resource_fields{$ns_uri}->{$el_name}){
		# rdf:resource
			if($person && $attname eq 'resource' && $attpre eq 'rdf') {
				if($ns_uri && $ns_uri ne $NAMESPACE) {
					$person->{$prefix}->{$el_name}=$val;
				}
				else {
				# foaf:***
					$person->{$el_name} = $val;
				}
			}
		}
	}
}

sub handle_end {
	my $self = shift;
	my $el   = shift;

#	print "end: $el\n";

	#----------------------------------
	# element
	#----------------------------------
	my ($prefix, $el_name) = split(':', $el);
	unless($el_name) {
		$el_name = $prefix;
		$prefix = '';
	}

	$self->pop_el;

	if($el_name eq 'Person') {
		my $person = $self->pop_person;
	}
}



#=============================================================================
1;
__END__


#!/usr/bin/perl
#=============================================================================
#----------------------------------------------------------------------------
# デバッガ
#----------------------------------------------------------------------------
use strict;
use lib qw(lib extlib);
use RNA::FOAF;
use Data::Dumper;

my $foaf_str = q(<rdf:RDF
  xmlns:foaf="http://xmlns.com/foaf/0.1/"
  xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
  xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
  xmlns:dc="http://purl.org/dc/elements/1.1/"
  xmlns:__semblog__="http://www.semblog.org/ns/semblog/0.1/">

 <foaf:Person>
  <foaf:mbox_sha1sum>c608c06ce564b0a00846eab72659d8f1375b880b</foaf:mbox_sha1sum>
  <foaf:mbox rdf:resource="mailto:webmaster@foo.com"/>
  <foaf:name>山田太郎</foaf:name>
  <foaf:title>Mr</foaf:title>
  <foaf:firstName>太郎</foaf:firstName>
  <foaf:surname>山田</foaf:surname>
  <foaf:nick>yamataro</foaf:nick>
  <foaf:homepage rdf:resource="http://www.aaa.com/"/>
  <foaf:depiction rdf:resource="" />
  <foaf:phone rdf:resource="tel:00-00-00" />
  <foaf:workplaceHomepage rdf:resource="http://workplace/" />
  <foaf:workInfoHomepage rdf:resource="http://workinfo" />
  <foaf:schoolHomepage rdf:resource="http://school" />

  <rdfs:seeAlso rdf:resource="http://hogehoge/foaf.rdf" />
  <__semblog__:foaftb rdf:resource="http://hogehoge/acsh.cgi"/>
  <__semblog__:rna rdf:resource="http://semsem/rna/" />
  <foaf:knows>
   <foaf:Person>
    <foaf:mbox_sha1sum>df0d8c6fa143ec27...</foaf:mbox_sha1sum>
   </foaf:Person>
  </foaf:knows>
  <foaf:knows>
   <foaf:Person>
    <foaf:mbox_sha1sum>9dff5368ce580062...</foaf:mbox_sha1sum>
    <rdfs:seeAlso rdf:resource="http://hogehoge/foaf.rdf" />
	<__semblog:foaftb rdf:resource="http://hogehoge/acsh.cgi" /> 
	<__semblog__:rna rdf:resource="http://hogehoge/rna/" />
   </foaf:Person>
  </foaf:knows>
 </foaf:Person>
</rdf:RDF>
);


my $foaf = new RNA::FOAF;
$foaf->parse($foaf_str);

print Dumper($foaf) . "\n\n\n";

print $foaf->person->name . "\n";

print $foaf->person->seeAlso . "\n";

print $foaf->person->knows->[-1]->seeAlso . "\n";
print $foaf->person->knows->[-1]->rna . "\n";

print "\n\n--------------------------\n";

# as_string
print $foaf->as_string;


