#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
# ハイパーリンク，Trackback 関連のモジュール
#
# $self->{
#	timeout => 120,   # HTTP アクセス時のタイムアウト [s]
#   tb_ping_list => 'cache/content/list',
#	_tb_ping_uri_list => {
#		'http://****/***.html' => {
#			tb_ping_uri=>'http://xxxx/xxx/mt-tb.cgi/4', 
#			'access_date'=>'Fri, 02 Jan 2004 18:56:20 GMT',
#			accessed => 1
#		},
#		'http://...' => {
#			tb_ping_uri=>'http://yyy/yy/mt-tb.cgi/7',
#			'access_date'=>'Fri, 02 Jan 2004 18:56:20 GMT'
#		},
#		...
#	}
#
#	link_info => {
#		'http://****/***.html' => $rss,
#		'http://...' => $rss2,
#		'http://...' => $rss3,
#		...
#	}
# }
# 
# '対象コンテンツのURI （たいていは HTML）' 
#	=> 'コンテンツのリンク情報を格納するRSS （RNA::RSS）'
#
#=============================================================================
package RNA::LinkInfo;

use strict;
use RNA;
use RNA::RSS;
use HTTP::Date;
use RNA::Utils qw( :all );
use Clone::PP qw(clone);
use vars qw($VERSION);

$VERSION = '0.1';

my $default_timeout = 180;
my $PREFIX = 'links';   # prefix of cache filename
my $NO_URI_FLAG = 'no uri';

# my $link_info 
#	= new RNA::LinkInfo(timeout=>$config->{Timeout}, tb_ping_list=>'list');
sub new {
	my $class = shift;
	my $self = {};
	
	bless $self, $class;
	
	$self->init(@_);
	
	return $self;
}

sub init {
	my $self = shift;
	my %hash = @_;

	$self->{timeout} = $hash{timeout} || $default_timeout;
	$self->{tb_ping_list} = $hash{tb_ping_list} || undef;

	$self->{link_info} = {};
	$self->{_tb_ping_uri_list} = {};
}


sub _write_tb_ping_list{
	my $self = shift;
	return undef unless($self->{tb_ping_list});
	
	my $str = '';
	while(my ($uri, $hash) = each %{$self->{_tb_ping_uri_list}}) {
		if($hash->{accessed}) {
		# アクセスがあったもののみ保存
			$str .= join("\t", 
				($uri, $hash->{'access_date'}, $hash->{tb_ping_uri})) . "\n";
		}
	}

#print STDERR $str;
	&print_file($self->{tb_ping_list}, \$str);
}

sub _read_tb_ping_list{
	my $self = shift;

	my $str = eval{&read_file($self->{tb_ping_list});};
	return undef if($@);

	foreach (split(/\r?\n/, $str)) {
		my ($uri, $access_date, $tb_ping_uri) = split(/\t/);
		$self->{_tb_ping_uri_list}->{$uri}
			= {'access_date'=>$access_date, tb_ping_uri=>$tb_ping_uri};
	}
}

# $self->_add_tb_ping_list(uri=>$content_uri, 'Last-Modified'=>$last_modified, 'access_date'=>$access_date, tb_ping_uri=>$tb_ping_uri);
sub _add_tb_ping_list{
	my $self = shift;
	my %hash = @_;

	$self->{_tb_ping_uri_list}->{ $hash{uri} }
			= {'access_date'=>$hash{'access_date'}, 
				tb_ping_uri=>$hash{tb_ping_uri},
				accessed => 1, };
#print STDERR $hash{uri}."\t".$hash{'Last-Modified'}."\t".$hash{tb_ping_uri}."\n";
}


# $hash_ref = $self->_get_cached_tb_ping_info(uri=>$content_uri);
sub _get_cached_tb_ping_info
{
	my $self = shift;
	my %hash = @_;

	return undef unless($self->{_tb_ping_uri_list}->{$hash{uri}});

	my $tb_ping_info = $self->{_tb_ping_uri_list}->{$hash{uri}};
	$tb_ping_info->{accessed} = 1;

	return $tb_ping_info;
}


# $link_hash_ref = $self->link_info;
sub link_info
{
	my $self = shift;
	return $self->{link_info};
}


# $self->build($items_list_ref);
#	$items_list_ref : array reference of RNA::RSS items
#
sub build
{
	my $self = shift;
	my $items_list_ref = shift;

	# read tb_ping_uri cache
	$self->_read_tb_ping_list;

	my @rss_array = ();
	foreach my $item (@{$items_list_ref}) {
		my $rss = new RNA::RSS;
		$rss->channel(%{$item});
		push @rss_array, $rss;
	}

	foreach my $rss (@rss_array) {
		$self->add($rss);
	}

	# write tb_ping_uri cache
	$self->_write_tb_ping_list;
}

# $self->add($rss);
sub add
{
	my $self = shift;
	my $rss = shift;
	my $uri = $rss->{channel}->{link};

	$rss = $self->get_link_info_rss($rss);

	#if ($rss->{items}->[0]->{link}) {
		$self->add_item(uri=>$uri, rdf=>$rss);
	#}
}

# $self->add_item(uri=>'http://***/***.html', rdf=>$rss)
sub add_item
{
	my $self = shift;
	my %hash = @_;

	my $uri = $hash{uri};
	my $rss = $hash{rdf};

	$self->{link_info}->{$uri} = $rss;
}


# $rss = $self->get_link_info_rss($rss);
#
#	RNA::RSS オブジェクトを返す
sub get_link_info_rss
{
	my $self = shift;
	my $rss = shift;
	my $uri = $rss->{channel}->{link};

	#--------------------------
	# trackback ping URI 特定
	#--------------------------
	my $tb_ping_uri = $NO_URI_FLAG;
	my $tb_ping_info = $self->_get_cached_tb_ping_info(uri=>$uri);
	if($tb_ping_info && $tb_ping_info->{tb_ping_uri}){
	# キャッシュされたものを用いる
		$tb_ping_uri = $tb_ping_info->{tb_ping_uri};
#print STDERR "Cached : ";
	}
	elsif ($rss->{channel}->{trackback}->{ping}) {
		$tb_ping_uri = $rss->{channel}->{trackback}->{ping};
#print STDERR "from RSS : ";
	}
	else {
		# html 文書を取得
		my ($str, $headers) 
			= &get_html(uri=>$uri, timeout=>$self->{timeout}, ua=>$RNA::NAME);
		convert_char_code(\$str);	# UTF-8 に変換

		if($str=~ /\<rdf:Description.*?trackback:ping=\"(.+?)\".*?\/?\s*\>/si){
			$tb_ping_uri = $1;
#print STDERR "GET : ";
		}

		# tb_ping_uri をキャッシュ
		$self->_add_tb_ping_list(uri=>$uri, 
				'Last-Modified'=>$headers->header('Last-Modified')||'', 
				tb_ping_uri=>$tb_ping_uri||'',
				access_date=>time2str()||'');
	}

#print STDERR "$uri\t$tb_ping_uri\n" if($tb_ping_uri);
	#--------------------------
	# trackback 情報の取得
	#--------------------------
	if($tb_ping_uri && $tb_ping_uri ne $NO_URI_FLAG) {
		# trackback CGI から情報取得
		my ($str, $headers) = &get_html(
			uri=> $tb_ping_uri . '?__mode=rss', timeout=>$self->{timeout}
			, ua=>$RNA::NAME);
		convert_char_code(\$str);	# UTF-8 に変換

		my $rss_tmp = new RNA::RSS;
		$rss_tmp->parse($str);
		$self->set_trackback_flag($rss_tmp);

		$rss->add_items(@{$rss_tmp->{items}});

		$rss->add_node($rss->{channel}, (trackback=>{ping=>$tb_ping_uri}));
	}

	#--------------------------
	# link 情報の取得
	#--------------------------
	{
#		my $target_str = $str; # from raw html (※content cache時は使用不可)
		my $target_str = $rss->{channel}->{description};
		my $rss_tmp = new RNA::RSS;
		while($target_str =~ s/(<|&lt\;)a\s+href=("|'|&quot\;)(.+?)("|'|&quot\;).*?(>|&gt\;)(.*?)(<|&lt\;)\/a(>|&gt\;)//si){
			my $uri = $3;
			my $content = $6;
			$content = $uri if(!$content);

			$rss_tmp->add_item(title=>$content, link=>$uri);
		}
		while($target_str =~ s/((http|ftp|https):\/\/[^\s<>"]+?)(\s|&lt;|&gt;|&quot;|>|<)//si){
			my $uri = $1;
			$rss_tmp->add_item(title=>$uri, link=>$uri);
		}

		$self->set_normal_link_flag($rss_tmp);
		$rss->add_items(@{$rss_tmp->{items}});
	}
	

	return $rss;
}


# $self->export_directory($dir);
#
sub export_directory
{
	my $self = shift;
	my $dir = shift;
	my %link_info = %{$self->{link_info}};

	$dir =~ s/\/$//;

	$self->clear_directory($dir);

	my $i = 1;
	foreach my $uri (keys %link_info) {
		my $rss = $link_info{$uri};
		
		my $filename = "$dir/$PREFIX" . '_' . sprintf("%010d", $i++) . '.rdf';
		my $str = $rss->as_string;

		&print_file($filename, \$str);
	}
}


# $self->export_additional($dir);
#
sub export_additional
{
	my $self = shift;
	my $dir = shift;

	my %link_info = %{$self->{link_info}}; # リンク情報をコピー

	$dir =~ s/\/$//;

	# $dir 下のファイルを１つずつ 読み，%link_infoにあるファイルは上書き．
	# 書き直したものについて，%link_info から delete 
	my $current_filename = '';
	foreach my $filename (glob($dir . '/*.rdf')) {
		$current_filename = $filename;
		my $rss = new RNA::RSS;
		$rss->parsefile($filename);

		my $uri = $rss->{channel}->{link};

		if($link_info{$uri}) {
			# overwrite the file
			my $str = $link_info{$uri}->as_string;
			&print_file($filename, \$str);

			# delete from %link_info
			delete $link_info{$uri};
		}
	}

	
	# 既存の最後尾ファイル番号の次の番号を取得
	my $idx = 1;
	if($current_filename =~ /$PREFIX\_(\d+)\.rdf/) {
		$idx = $1 + 1;
	}

	# %link_info のRSSをファイル保存
	while( my($uri, $rss) = each %link_info) {
		my $filename = "$dir/$PREFIX" .'_'. sprintf("%010d", $idx++) . '.rdf';
		my $str = $rss->as_string;

		&print_file($filename, \$str);
	}
}


# $self->clear_directory($dir);
sub clear_directory
{
	my $self = shift;
	my $dir = shift;

	unlink(glob($dir . '/*.rdf'));
}


# $self->import_directory($dir);
#
sub import_directory
{
	my $self = shift;
	my $dir = shift;
	my %link_info = %{$self->{link_info}};

	$dir =~ s/\/$//;

	foreach my $filename (glob($dir . '/*.rdf')) {
		my $rss = new RNA::RSS;
		$rss->parsefile($filename);

		my $uri = $rss->{channel}->{link};
		if($uri) {
			$self->add_item(uri=>$uri, rdf=>$rss);
		}
	}
}

# $self->import_object($obj);
#    $obj : LinkInfo オブジェクト
sub import_object
{
	my $self = shift;
	my $obj = shift;
	my $target_link_info  = clone($obj->{link_info});

	while (my ($uri, $rss) = each %{$target_link_info}) {
		$self->add_item(uri=>$uri, rdf=>$rss);
	}
}


# $self->set_trackback_flag($rss);
sub set_trackback_flag
{
	my $self = shift;
	my $rss = shift;

	foreach my $item (@{$rss->{items}}) {
		$rss->add_node($item, (semblog=>{in=>$item->{link}}));
	}
}

# $self->set_normal_link_flag($rss);
sub set_normal_link_flag
{
	my $self = shift;
	my $rss = shift;

	foreach my $item (@{$rss->{items}}) {
		$rss->add_node($item, (semblog=>{out=>$item->{link}}));
	}
}


# $self->reduce;
sub reduce
{
	my $self = shift;

	foreach my $rss (values %{$self->{link_info}}) {
		foreach my $item (@{$rss->{items}}) {
			delete $item->{description};
		}
	}
}

#==============================================================================
1;
__END__

