package RNA::RSD;
#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
#
# RSD ֘ÃW[
#	http://archipelago.phrasewise.com/rsd
#=============================================================================

use strict;
use Carp;
use XML::SAX::PurePerl;
use RNA::Utils qw( :all );
use vars qw($VERSION);

$VERSION = '0.1';

my $DEFAULT_VERSION = '1.0';
my $DEFAULT_ENCODING = 'UTF-8';
my $NAMESPACE = 'http://archipelago.phrasewise.com/rsd';

my %rsd_field = (
	service => {
		engineName => '',
		engineLink => '',  # engine ̔s.
		homePageLink => '', # 

		apis => [],
		# apis => [
		#	{
		#		name => '',  # API name
		#		preferred => '',   # true or false
		#		apiLink => 'http://', #
		#		blogID => '1',
		#	}
		# ]
	}
);


sub new {
    my $class = shift;
	my $self = {};
    
    bless $self, $class;
    
    $self->init(@_);
    
    return $self;
}


sub init {
    my $self = shift;
    my %hash = @_;

	%{$self} = %rsd_field;
	
    # modules
    $self->{modules} = {};

    #get version info
    (exists($hash{version}))
	? ($self->{version} = $hash{version})
	    : ($self->{version} = $DEFAULT_VERSION);

    # encoding
    (exists($hash{encoding}))
	? ($self->{encoding} = $hash{encoding})
	    : ($self->{encoding} = $DEFAULT_ENCODING);
}

sub apis
{
	my $self = shift;
	return $self->{service}->{apis} || [];
}

sub as_string {
	my $self = shift;
	my $version = $self->{version};
	my $encoding = $self->{encoding};
	my $output = '';

	$output .= qq(<?xml version="1.0" encoding="$encoding" ?>
<rsd version="$version" xmlns="$NAMESPACE">
);

	#----------------------
	# service
	#----------------------
	$output .= "\t<service>\n";

	my $service = $self->{service};
	foreach my $el (keys %{$service}) {
		if($service->{$el} && $el ne 'apis') {
			$output .= "\t\t<$el>" . encode($service->{$el}) . "</$el>\n";
		}
	}

	# <apis>
	my $apis = $service->{apis};
	$output .= "\t\t<apis>\n";
	foreach my $api (@{$apis}) {
		$output .= $self->as_string_api($api);
	}
	$output .= "\t\t</apis>\n";

	$output .= "\t</service>\n";

	$output .= "</rsd>\n";

	return $output;
}

# $str = $self->as_string_api($api);
sub as_string_api {
	my $self = shift;
	my $api = shift;

	my $output = '';
	my $attributes = '';
	my $content = '';
	foreach my $el (keys %{$api}) {
		my $val = $api->{$el};
		$attributes .= " $el=\"" . encode($val) . "\"";
	}
	$output .= "\t\t<api" . $attributes . " />\n";

	return $output;
}


sub add_api {
	my $self = shift;
	my $hash_ref = {@_};

	push (@{$self->{service}->{apis}}, $hash_ref);
}




# $self->parse($str)
#
sub parse {
	my $self = shift;
	$self->init((%$self));

	my $str = shift;
	my $handler = RSDParseHandler->new(Result => $self);
	my $parser = XML::SAX::PurePerl->new(Handler => $handler);

	# for the perl version less then 5.7.2
	$str =~ s/encoding=["'].+?['"](.*?\?>)/$1/i;

	$parser->parse_string($str);
}

sub parsefile {
	my $self = shift;
	my $file = shift;
	open(IN, $file) || croak "Cannot open file $file : $!";
	my $str = "";
	while(my $s = <IN>){
		$str .= $s;
	}
	$self->parse($str);
}


# $result = &RNA::OPML::encode ($text);
sub encode {
	my $text = shift;
	
	$text =~ s/</&lt;/g;
	$text =~ s/>/&gt;/g;
	$text =~ s/"/&quot;/g;

	return $text;
}

#=============================================================================

package RSDParseHandler;

use strict;

sub new {
	my $class = shift;
	my %opts = @_;

	my $self = \%opts;
	bless $self, $class;

	$self->reset;
	return $self;
}

sub reset
{
	my $self = shift;
	$self->{ElementStack} = [];
	$self->{CurrentElementName} = '';
}

sub set_current_element_name
{
	my $self = shift;
	my $name = shift;

	$self->{CurrentElementName} = $name;
}

sub get_current_element_name
{
	my $self = shift;
	return $self->{CurrentElementName};
}

# $self->push_stack($elment);
sub push_stack
{
	my $self = shift;
	my $element = shift;	# reference or element_name

	push(@{$self->{ElementStack}}, $element);
}

# $elment = $self->pop_stack;
sub pop_stack
{
	my $self = shift;
	return pop @{$self->{ElementStack}};
}

# $elment_ref = $self->end_of_stack;
sub end_of_stack
{
	my $self = shift;
	return $self->{ElementStack}->[-1];
}

# DocumentHandler
sub set_document_locator {
	my $self = shift;
# 	print "set_document_locator\n";
}

sub start_document {
	my $self = shift;
#	print "start_document\n";	
	$self->reset;
}

sub end_document {
	my $self = shift;
#	print "end_document\n";

	my $result = $self->{Result};
	$result->{service} = $self->{service};
}

sub start_element {
	my $self = shift;
#	print "start_element\n";
	my $el = shift;

	my $element_name = $el->{LocalName};

	# set current element name 
	$self->set_current_element_name($element_name);

	# element
	my $element = {};
	my $parent = $self->end_of_stack();

	if($element_name eq 'service') {
	# <service>
		$parent->{$element_name} = {};
		$element = $parent->{$element_name};
	}
	elsif($element_name eq 'apis') {
	# <service>
		$parent->{$element_name} = [];
		$element = $parent->{$element_name};
	}
	elsif($element_name eq 'api') {
	# <api> element
		foreach my $attr (values %{$el->{Attributes}}) {
			my $name = $attr->{LocalName};
			my $value = $attr->{Value};

#				print "$name : $value\n";
			$element->{$name} = $value;
		}
		push(@{$parent}, $element);
	}
	elsif($element_name eq 'rsd') {
	}
	else {
	# <tag></tag>
		$parent->{$element_name} = '';
		$element = $parent->{$element_name};
	}

	# push stack
	if($element_name eq 'rsd') {
		$self->push_stack($self);
	}
	else{
		$self->push_stack($element);
	}
}

sub end_element {
	my $self = shift;
#	print "end_element\n";
	my $el = shift;

	my $element_name = $el->{LocalName};

	# clear current element name 
	$self->set_current_element_name('');

	# pop stack
	my $pop_el = $self->pop_stack;
}

sub characters {
	my $self = shift;
	my $node  = shift;
	my $str = $node->{Data}; 
#   warn "Char: ", $node->{Data}, "\n";
#   print "characters\n";

	if ($str =~ /^\s+$/) {
		return;
	}

	my $element_name = $self->get_current_element_name;
	unless($element_name) {
		return;
	}
	if($element_name eq 'service' || $element_name eq 'rsd' 
		|| $element_name eq 'apis' || $element_name eq 'api') 
	{
		return ;
	}
	
	$self->{service}->{$element_name} = $str;
}

sub processing_instruction {
	my $self = shift;
#	print "processing_instruction\n";
}

sub ignorable_whitespace {
	my $self = shift;
#	print "ignorable_whitespace\n";
}

# LexHandler
sub comment {
	my $self = shift;
#	print "comment\n";
}

# DTDHandler
sub notation_decl {
	my $self = shift;
#	print "notation_decl\n";
}

sub unparsed_entity_decl {
	my $self = shift;
#	print "entity_decl\n";
}

# EntityResolver
sub resolve_entity {
	my $self = shift;
#	print "resolve_entity\n";
	return '';
}




#=============================================================================
1;
__END__

