#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================

#=============================================================================
# Utilities
#=============================================================================
package RNA::Utils;
use strict;

use LWP::UserAgent;
use CGI::Carp;
use HTTP::Date qw(time2str str2time time2iso time2isoz);
use Time::Zone;

use Exporter;
@RNA::Utils::ISA = qw( Exporter );
use vars qw( @EXPORT_OK @EXPORT %EXPORT_TAGS $TIME_ZONE $ENCODE_MODULE);
# @EXPORT = qw();
my @simbol_list = 
	qw( get_current_dc_date transform_to_dc_date transform_to_w3cdtf
		calc_day_of_week dc_date 
		dcdate_to_rfc822 parse_date_string date2ymdhms_local dc2ymd 
		diff_date comp_dc_date comp_date format_date
		is_private_ip_address get_html 
		set_rss print_file read_file 
		html_encode html_encode2 html_encode_minimal html_decode 
		die_handler url_encode url_decode url_encode_minimal
		clear_directory convert_char_code first_n_letters);
@EXPORT_OK = @simbol_list;
%EXPORT_TAGS = (all => [@simbol_list]);

# time zone
BEGIN {
	my $offset = &tz_offset;
	my $sign = $offset >= 0 ? '+' : '-';
	my $tz = $sign . sprintf("%02d:00", abs($offset) / 60 / 60);
	$TIME_ZONE = $tz;
}

# charset 
BEGIN {
	eval {require Encode;};
	if($@) {
	# use Jcode.pm
		require Jcode;
		$ENCODE_MODULE = 0;
	}
	else{
	#use Encode.pm
		import Encode qw(from_to);
		require Encode::Guess;
		require Encode::Alias;
		$ENCODE_MODULE = 1;
	}
}


#-----------------------------------------------------------------------------
# 
#-----------------------------------------------------------------------------


# &set_rss($rss, $title, $link, $description, $date, $creator, $language);
sub set_rss
{
	my ($rss, $title, $link, $description, $date, $creator, $language) = @_;

	$rss->channel(
		title 		=> $title,
		link		=> $link,
		description	=> $description,
		dc => {
			date       => $date,
			creator    => $creator,
			language   => $language
		},
	);
	
	$rss->add_module(prefix=>'cc', uri=>"http://web.resource.org/cc/");
}

#-----------------------------------------------------------------------------
# Net
#-----------------------------------------------------------------------------

# Check if the IP address is private address
# メモ : IPV6 対応の場合は、Net::IP を使う
#
# class A 10.0.0.0    - 10.255.255.255
# class B 172.16.0.0  - 172.31.255.255
# class C 192.168.0.0 - 192.168.255.255
#
# $bool = &is_private_ip_address($addr);
sub is_private_ip_address
{
	my ($o1, $o2, $o3, $o4) = split(/\./, shift);

	if ($o1 eq 10 # class A
		|| $o1 eq 172 && $o2 >= 16 && $o2 <= 31  # class B
		|| $o1 eq 192 && $o2 eq 168 # class C
	) {
		return 1;
	}
	return 0;
}


# ($html, $headers) = &get_html(uri=>$uri, timeout=>$sec, 
#		'If-Modified-Since'=>$date, ua=>'RNA 1.9');
#
# $headers : HTTP::Headers
sub get_html
{
	my %arg = @_;
	my $uri = $arg{uri};
	$uri =~ s/\&amp\;/&/gs;
	my $timeout = $arg{timeout};
	my $if_modified_since = $arg{'If-Modified-Since'};

	my $req = HTTP::Request->new(GET => $uri);
#	$req->header('Accept' => 'text/html');

	# 'If-Modified-Since' を指定
	if($if_modified_since) {
		$req->header('If-Modified-Since' => $if_modified_since);
	}
	
	# authorization
#	$req->authorization_basic('user', 'passwd');

	# send request 
	my $ua = LWP::UserAgent->new;
	$ua->agent($arg{ua} . ' ' . $ua->agent);
	if($timeout) { # timeout
		$ua->timeout($timeout);
	}
	$ua->parse_head(0); # HTML::HeadParser を必要としないように  
	my $res = $ua->request($req);

	# http header
	my $headers = $res->headers();

	# check
	if ($res->is_success) {
#print $res->content;
		return ($res->content, $headers);
	}
	else {
#		print "Error: " . $res->status_line . "\n";
		return ('', $headers);
	}
}


# clear_directory($dir)
sub clear_directory
{
	my $dir = shift;
	$dir =~ s/\/$//;
	$dir =~ s/\\$//;

	unlink(glob($dir . '/*'));
}

#-----------------------------------------------------------------------------
# 日付の計算
#-----------------------------------------------------------------------------

# W3CDTF
# $dc_date = get_current_dc_date;
sub get_current_dc_date
{
	my $iso_date = &time2iso(time);
	$iso_date =~ s/ /T/;
	return $iso_date . $TIME_ZONE;
}

# Auto detect of date format and transformation to W3CDTF format
#
# $w3cdtf_date = &transform_to_w3cdtf($unknown_date_format)
sub transform_to_w3cdtf
{
	my $str = shift;
	my $time = str2time($str);
	return undef unless $time;

	# ローカルの TIME ZONE で返す
	my $iso = HTTP::Date::time2iso($time);
	$iso =~ s/\s+/T/;
	return $iso . $TIME_ZONE;

#	my ($year, $month, $day, $hour, $min, $sec, $tz) 
#		= HTTP::Date::parse_date($str);
#	if($tz =~ /([-+])(\d+):(\d+)/) {
#		# no
#	}
#	else {
#		my $offset = &tz_offset($tz);
#		$tz = sprintf("%02d:00", $offset / 60 / 60);
#		$tz = '+' . $tz if ($offset >= 0);
#	}
#
#	return &dc_date($year, $month, $day, $hour, $min, $sec, $tz);
}


# Auto detect of date format and transformation to Dublin Core format
# (※ Old routine.)
#
# $dc_date = &transform_to_dc_date($unknown_date_format)
sub transform_to_dc_date
{
	my $date = shift;

	return transform_to_w3cdtf($date);

}

# ($wday) = calc_day_of_week($y, $m, $d);
#
# ツェラーの公式
#
# $wday ---  0:日曜日, 1:月曜日, 2:火曜日,3:水曜日, 4:木曜日, 5:金曜日,6=土曜日
#
sub calc_day_of_week
{
	my ($y, $m, $d) = @_;
	my $wday = 0;

	if ($m == 1 || $m == 2){ 
		$y--; 
		$m += 12;
	}
	
	$wday = ($y + int($y/4) - int($y/100) + int($y/400)
				+ int(2.6*$m+1.6) + $d) % 7;

	return $wday;
}


# 2003-05-10T22:57:49 
# $str = &dc_date($year, $month, $day, $hour, $minute, $second, $zone)
sub dc_date
{
	my ($year, $month, $day, $hour, $minute, $second, $zone) = @_;
	return sprintf("%4d-%02d-%02dT%02d:%02d:%02d%s",
		$year,$month,$day,$hour,$minute,$second, $zone);
}


# $rfc822date = &dcdate_to_rfc822($dc_date);
#
# http://asg.web.cmu.edu/rfc/rfc822.html#sec-5
#    e.g.)	Sun, 29 Sep 2002 19:59:01 GMT
#
sub dcdate_to_rfc822
{
	my $dc_date = shift;
	my ($y, $M, $d, $h, $m, $s, $z) = &parse_date_string($dc_date);

	my %month_hash = (
		'01' => 'Jan', '02'=>'Feb', '03'=>'Mar', '04'=>'Apr', 
		'05'=>'May', '06'=>'Jun', '07'=>'Jul', '08'=> 'Aug', 
		'09'=>'Sep', '10'=>'Oct', '11'=>'Nov', '12'=>'Dec');

	# month
	my $month = $month_hash{sprintf("%02d", $M)};

	# calc  day-of-week (Zeller)
	my @wday_ar = ('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat');
	my $wday = &calc_day_of_week($y, $M, $d);
	my $wday_str = $wday_ar[$wday];

	# time zone   +0900
	$z =~ s/://;
	
	return sprintf("%s, %02d %s %s %02d:%02d:%02d %s", 
		$wday_str, $d, $month, $y, $h, $m, $s, $z);
}


# ($y, $M, $d, $h, $m, $s, $z) = &parse_date_string($dc_date);
#
# $z : +09:00   -04:00 など
sub parse_date_string
{
	my ($year, $month, $day, $hour, $min, $sec, $tz) 
		= HTTP::Date::parse_date(shift);

	return ($year, $month, $day, $hour, $min, $sec, $tz);
}


# 'YYYYMMDDhhmmss' local timezone
sub date2ymdhms_local
{
	my $time = str2time(shift);
	return '00000000000000' unless $time;

	# iso format(w3cdtf) in the local time zone
	# 'YYYY-MM-DD hh:mm:ss'
	my $iso = HTTP::Date::time2iso($time);

	# 'YYYYMMDDhhmmss'
	$iso =~ s/[-:\s]//g;

	return $iso;
}


# 'yyyyMMddhhmmss' GMT 
#
# !! date2ymdhms_local() と同じロジックに書き換えたい !!
#
sub dc2ymd
{
	my $dc = shift;

	unless($dc) {
		return '0';
	}

	my ($ymd, $time) = split(/T/, $dc);
	my ($y, $M, $d) = split(/-/, $ymd);
	$time =~ /(\d+):(\d+):(\d+)(.*)/i;
	my ($h, $m, $s, $z) = ($1, $2, $3, $4);

	my $ret_value = sprintf("%4d%02d%02d%02d%02d%02d", $y, $M, $d, $h, $m, $s);
	

	# タイムゾーンに関して
	if($z =~ /([-+])(\d+):(\d+)/i){
		my ($zf, $zh, $zm) = ($1, $2, $3);

		my $diff = sprintf("%02d%02d00", $zh, $zm);
		if($zf eq '-') {
			$ret_value += $diff;
		}
		else {
			$ret_value -= $diff;
		}
	}

	return $ret_value;
#	return ($y, $M, $d, $h, $m, $s);
}

# $diff_sec = &diff_date($date_str1, $date_str2);
# 	returen $date_str1 - $date_str2  [sec]
sub diff_date
{
	my($date1, $date2) = @_;

	$date1 = &str2time($date1) || 0;
	$date2 = &str2time($date2) || 0;

	return $date1 - $date2;
}


# $result = &comp_date($date1, $date2);
# 	$date1 <  $date2  :  -
# 	$date1 == $date2  :  0 
# 	$date1 >  $date2  :  +, 
sub comp_date
{
	my ($date1, $date2) = @_;
	$date1 = &str2time($date1);
	$date2 = &str2time($date2);
	$date1 ||= 0;
	$date2 ||= 0;

	return $date1 <=> $date2;
}


# !!! this routine will be replaced by comp_date() !!!
# 
# 2003-05-10T22:57:49+09:00
# $result = &comp_dc_date($dc_date1, $dc_date2);
# 	$dc_date1 < $dc_date2  :  -
# 	$dc_date1 == $dc_date2 :  0 
# 	$dc_date1 > $dc_date2  :  +, 
sub comp_dc_date
{
	my($dc_date1, $dc_date2) = @_;
	return &dc2ymd($dc_date2) <=> &dc2ymd($dc_date1);
}


# $formated_str = &format_date($format_str, $date_str);
#    %a : abbreviated weekday    (e.g. Mon, Thu)
#    %A : weekday                (e.g.Monday, Thursday)
#    %b : abbreviated month name (e.g.Jan, Sep)
#    %B : month name.            (e.g. September)
#    %d : day of the month, two digits, (e.g. 09, 01)
#    %e : day of the month,      (e.g. ' 9') 
#    %H : 24-hour clock.         (e.g. 16, 03) 
#    %I : 12-hour clock,         (e.g. 04, 11)
#    %j : day of the year.       (e.g. 056)       * not implimented 
#    %k : 24-hour clock.         (e.g. ' 9')
#    %l : 12-hour clock          (e.g. ' 4'). 
#    %m : month, two digits,     (e.g. 09) 
#    %M : minute, two digits.    (e.g. 02)
#    %p : Either AM or PM        (e.g. AM)
#    %S : second, two digits,    ( e.g. 04)
#    %x : language-aware date representation.    * not implemented
#    %X : language-aware time representation.    * not implemented
#    %y : year, two digits,      (e.g. 01) 
#    %Y : year, four digits.     (e.g. 2001)
sub format_date
{
	my ($form_str, $date_str) = @_;
	my @wdays 
		= qw( Sunday Monday Tuesday Wednesday Thursday Friday Saturday );
	my @months = qw( January February March April May June
				July August September October November December );
	my @ampm = qw(AM PM);

	# parse date
	my ($year, $month, $day, $hour, $min, $sec, $tz) 
		= HTTP::Date::parse_date($date_str);

	my $wday = &calc_day_of_week($year, $month, $day);

	# hash に割り当て
	my %conv = (
		a => substr($wdays[$wday], 0, 3), 
		A => $wdays[$wday],
		b => substr($months[$month - 1], 0, 3),
		B => $months[$month - 1],
		d => sprintf("%02d", $day),
		e => sprintf("%2d", $day),
		H => sprintf("%02d", $hour),
		I => sprintf("%02d", $hour % 12),
		#   %j : day of the year.       (e.g. 056)       * not implimented 
		k => sprintf("%2d", $hour),
		l => sprintf("%2d", $hour % 12), 
		m => sprintf("%02d", $month), 
		M => sprintf("%02d", $min),
		p => $ampm[int($hour / 12)],
		S => sprintf("%02d", $sec), 
		#    %x : language-aware date representation.    * not implemented
		#    %X : language-aware time representation.    * not implemented
		y => sprintf("%02d", substr($year, -2, 2)),
		Y => sprintf("%04d", $year),
		Z => $tz
	);
	my $key = join('|', keys %conv);
	$form_str =~ s/\%($key)/$conv{$1}||$1/ges;

	return $form_str;
}



#-----------------------------------------------------------------------------
# File
#-----------------------------------------------------------------------------

# &print_file($file, \$str, $mode);
sub print_file
{
	my ($file, $str_ref, $mode) = @_;
	$mode ||= '>';

	my $str = $$str_ref;
	open(OUT, "$mode$file") 
		|| croak "Content-Type: text/plain\n\n $file : $!\n";
	flock(OUT, 2);
	print OUT $str;
	flock(OUT, 8);
	close(OUT);
}

# $str = &read_file($file)
sub read_file
{
	my $file = shift;
	
	open(IN, $file) || croak "Content-Type: text/plain\n\n $file : $!\n";
	my $str = "";
	while(my $s = <IN>){
		$str .= $s;
	}
	close(IN);

	return $str;
}

#-----------------------------------------------------------------------------
# Encode, Decode
#-----------------------------------------------------------------------------


# $result = &html_encode($str)
sub html_encode
{
	my ($t) = @_;
	my %cv = ('&' => '&amp;', '"' => '&quot;',
		'<' => '&lt;',  '>' => '&gt;');
	$t =~ s/([&<>"])/$cv{$1}||$1/ge;
	$t;
}

# !!! obsolete  !!!!
#
#
# $result = &html_encode2($str)
sub html_encode2
{
	my ($t) = @_;
	return html_encode(html_decode($t));
}

# $result = &html_encode_minimal($str)
sub html_encode_minimal
{
	my ($t) = @_;
	my %cv = ('"' => '&quot;', '<' => '&lt;',  '>' => '&gt;');
	$t =~ s/([<>"])/$cv{$1}||$1/ge;
	$t;
}

# $result = &html_decode($str)
sub html_decode 
{
	my ($t) = @_;
	my %cv = ('&amp;' => '&', '&quot;'=> '"',
		'&lt;' => '<', '&gt;' => '>');
	my $s = join('|', keys %cv);
	$t =~ s/($s)/$cv{$1}||$1/ge;
	$t;
}

sub die_handler {
	my $msg = shift;
	$msg = html_encode($msg);

	print "Content-Type: text/html; charset=UTF-8\n\n";
	print qq(<html>
	<head>
		<title>Error Occured</title>
		<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
	</head>
	<body bgcolor="#eeeeee" text="#333333">
		<h2>Error Occured</h2><br>
		$msg
	</body>
</html>
);

	exit(1);
}


# $str = &url_encode($str)
sub url_encode
{
	my $arg = shift;
#	$arg =~ s/(\W)/'%'.unpack("H2", $1)/ego;
	$arg =~ s/([^a-zA-Z0-9_.!~*'()-])/'%'.unpack('H2', $1)/ego;
	$arg =~ tr/ /+/; 

	return $arg;
}

# $url = &url_encode_minimal($url)
#   target : <  >  "
#
sub url_encode_minimal
{
	my $arg = shift;
	$arg =~ s/([><"])/'%'.unpack('H2', $1)/ego;

	return $arg;
}


# $str = &url_decode($str)
sub url_decode
{
	my $arg = shift;
	$arg =~ tr/+/ /;
	$arg =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/ego;

	return $arg;
}

# character code conversion
#
# convert_char_code(\$str, $enc_to, $enc_from);
my $default_encoding = 'UTF-8';

sub convert_char_code
{
	my $str_ref = shift;
	my $enc_to = shift || $default_encoding;
	my $enc_from = shift || undef;

	my %encode_list = ('utf-8'=>'utf8', "euc-jp"=>'euc-jp', 
		'shift_jis'=>'sjis');
	$enc_to   = $encode_list{lc($enc_to)}  ||$enc_to;
	$enc_from = $encode_list{lc($enc_from)}||$enc_from;

	if($$str_ref)  {
		if(!$ENCODE_MODULE) {
		# use Jcode.pm
			$enc_to = 'euc' if($enc_to eq 'euc-jp');

			if($enc_from){
				Jcode::convert($str_ref, $enc_to, $enc_from);
			}
			else {	
				Jcode::convert($str_ref, $enc_to);
			}

			return 1;
		}
		else {
		# use Encode.pm
			Encode::Alias::define_alias( 'sjis' => 'shiftjis' );
			my @suspects_list = qw(euc-jp shiftjis 7bit-jis);
			my $decoder = Encode::Guess::guess_encoding($$str_ref, @suspects_list);
			if ($enc_from) {
			# enc_from is specified
				from_to($$str_ref, $enc_from, $enc_to);
				return 1;
			}
			elsif(ref $decoder){
			# successful guess
				from_to($$str_ref, $decoder->name, $enc_to);
				return 1;
			}else{
			# guess failed
				if($$str_ref =~ /encoding=["'](.+?)["']/s) {
				# XML Declaration
					my $from_name = '';
					if($from_name = $encode_list{lc($1)}||$1){
						eval{from_to($$str_ref, $from_name, $enc_to);};
						if($@) {return 0;}
						else   {return 1;}
					}
				}
			}
		}
	}

	return 0;
}


# RNA::Utils::execute_sub_routine(\&sub, $is_background);
sub execute_sub_routine
{
	my ($sub_routine, $is_background) = @_;
	
	if($is_background) {
	# バックグラウンド処理
		my $pid = '';
		$|=1; # 即時出力
		if($pid = fork) {
			# 親プロセス
			return 1;
		}
		elsif (defined $pid) {
			# 子プロセス
			close(STDOUT);
			&$sub_routine;
			exit;
		}
		else {
		# エラー
			croak("Can't generate process.");
		}
	}
	else {
	# 通常の処理
		&$sub_routine;
		return 1;
	}
}


my $UTF8_REGEXP = 
	'[\x00-\x7F]'                   # UCS-2
	. '|[\xC0-\xDF][\x80-\xBF]'     # UCS-2
	. '|[\xE0-\xEF][\x80-\xBF]{2}'  # UCS-2
	. '|[\xF0-\xF8][\x80-\xBF]{3}'  # UCS-4
	. '|[\xF8-\xFB][\x80-\xBF]{4}'  # UCS-4
	. '|[\xFC-\xFD][\x80-\xBF]{5}';  # UCS-4

# $first_n_letters = &first_n_letters(str=>$str, n=>$n, enc=>'UTF-8');
# 
# 
sub first_n_letters
{
	my %arg = @_;
	my $enc = lc($arg{enc} || 'UTF-8');
	my $str = $arg{str};
	my $n = $arg{n};

	# convert character code
	&convert_char_code(\$str, 'UTF-8') if($enc ne 'utf-8');
#print STDERR ($enc ne 'utf-8') ? 'it\'s not UTF-8' : 'utf-8';

	$str = $1 if($str =~ /^(($UTF8_REGEXP){0,$n})/s);

	# convert character code
	&convert_char_code(\$str, $enc) if($enc ne 'utf-8');

	return $str;
}


1;
__END__

