#!/usr/bin/perl
#=============================================================================
# using FOAF on RNA 
#=============================================================================
#
# FOAF を使用した RNA間連携
#
#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================

# ライブラリ
use strict;
use lib qw(lib extlib);
use CGI;
use RNA;
use RNA::RSS;
use RNA::AntennaTree;
use RNA::Net::Bulkfeeds;
use RNA::Utils qw( :all );
use RNA::FOAF;
use XMLRPC::Lite;
use RNA::RSS::WebEdit;
use RNA::AutoDiscovery;
use RNA::RSD;
use RNA::Alliance;

# XML::Parser の使用を抑止．（XML::Parser::Lite を使用）
$SOAP::Constants::DO_NOT_USE_XML_PARSER = 1;


my $cgi = new CGI;
$cgi->param;
&die_handler($cgi->cgi_error) if ($cgi->cgi_error);

#----------------------------------
# 基本設定
#----------------------------------
my $self_uri = $cgi->url(-relative=>1);
my $self_uri_with_query = $cgi->self_url;


#==============================================================================
# main
#==============================================================================

# RNA オブジェクトの生成
my $rna = RNA->new(Config => './config.pl');
my $config = $rna->{Config};

#----------------------------------
# 認証
#----------------------------------
if($config->{Authentication}->{AllianceCGI}) {
	unless($rna->authenticate(cgi=>$cgi)){
		print $cgi->redirect($config->{AuthenticationCGIURI} 
					. '?transfer=' . url_encode($self_uri_with_query));
		exit;
	}
}


# action
my $action = $cgi->param('action');
my $friend_rna_uri = $cgi->param('rna_uri');
my $friend_rna_xmlrpc_uri = '';
if($friend_rna_uri) {
	$friend_rna_xmlrpc_uri = get_xmlrpc_uri($friend_rna_uri);
}


if($friend_rna_uri) {
# Alliance with other RNA
	if($action =~ /getDate/i){
	# getDate
		&get_date(rna=>$friend_rna_uri, rpc=>$friend_rna_xmlrpc_uri);
	}
	elsif($action =~ /compareSites/i){
	# compareSites
		&compare_sites(rna=>$friend_rna_uri, rpc=>$friend_rna_xmlrpc_uri);
	}
	else {
		$rna->error_log(message=>"Invalid action : $action", die=>1);
	}
}
elsif($action =~ /recommend/i){
	my $transfer_uri = $self_uri;
	my $response = $cgi->redirect($transfer_uri);
	if($config->{Update}->{Background}) {
	# バックグラウンド処理
		$response = $rna->transfering_page(transfer_uri => $transfer_uri);
	}

	RNA::Utils::execute_sub_routine(
		\&recommend_sites, $config->{Update}->{Background});
	print $response;
}
elsif($action =~ /site_search/i){
# Site search (bulkfeeds)
	my $engine = $cgi->param('engine') || '';
	my $keyword  = $cgi->param('keyword') || '';
	my $field  = $cgi->param('field') || 'title';

	&search_sites(engine=>$engine, keyword=>$keyword, field=>$field);
}
else{
	&show_page;
}

#=============================================================================
# Sub routine
#=============================================================================


# &recommend_sites;
sub recommend_sites
{
	my $alliance = new RNA::Alliance(RNA=>$rna);
	$alliance->make_recomended_site_list;
	$alliance->print_recommended_site_list;

	# log
	$rna->info_log(message=>"recommend_sites");
}

# ※ RNA::Alliance オブジェクトのものに変更予定
# $foaf = &get_foaf;
sub get_foaf
{
	my ($foaf_str, $headers) = 
		&get_html(uri=>$config->{FOAF}->{URI}, timeout=>$config->{Timeout}
			, ua=>$RNA::NAME);
	my $foaf = new RNA::FOAF;
	eval {$foaf->parse($foaf_str);};
	if($@) {
		$rna->error_log(message=>"Invalid FOAF file  $config->{FOAF}->{URI}", die=>1);
		return undef;
	}
	else {
		return $foaf;
	}
}

# $xmlrpc_uri = get_xmlrpc_uri($rna_uri);
sub get_xmlrpc_uri
{
	my $rna_uri = shift;

	my ($str, $headers) = 
		&get_html(uri=>$rna_uri, timeout=>$config->{Timeout}
			, ua=>$RNA::NAME);
	my $link = RNA::AutoDiscovery->new(html=>$str)->search('title', 'RSD');
	my $rsd_uri = $link->{href};

	($str, $headers) = 
		&get_html(uri=>$rsd_uri, timeout=>$config->{Timeout}
			, ua=>$RNA::NAME);
	my $rsd = new RNA::RSD;
	$rsd->parse($str);

	foreach my $api (@{$rsd->apis}) {
		if(lc($api->{name}) eq 'rna') {
			return $api->{apiLink};
		}
	}

	return $rna_uri . 'rna-xmlrpc.cgi';
}

# &show_page;
sub show_page
{
	# FOAF
	my $foaf = &get_foaf;

	my @knows = @{$foaf->person->knows};

	# <select>
	my $select = "<select name=\"rna_uri\">\n";
	$select .= "<option value=\"\"> -- friends' RNA -- </option>\n";
	foreach my $p (@knows) {
		my $name = encode($p->nick||$p->name);
		my $mbox = encode($p->mbox||$p->mbox_sha1sum);

		# URI of the friends' RNA
		my $rna_uri = escape_uri($p->rna);
#		unless($rna_uri) {
#			foreach my $seeAlso (@{$p->seeAlso}) {
#				if (lc($seeAlso->{dc}->{title}) eq lc('RNA')) {
#					$rna_uri = $seeAlso->{rdf}->{resource};
#				}
#			}
#		}

		if($rna_uri) {
			$rna_uri =~ s/\/$//;
			$rna_uri .= '/';
			$select .= "<option value=\"$rna_uri\">$rna_uri &nbsp\;&nbsp\;- $name [$mbox]</option>\n";
		}
	}
	$select .= "</select>\n";

	#-------------------------
	# テンプレート
	#-------------------------
	my $template = &read_file($config->{Template}->{Alliance});
	my %text_hash = %{$config->{Template}->{Element}};
	$text_hash{__RNAFOAFSelect__}  = $select;

	foreach my $t (keys %text_hash){
		$template =~ s/\<\$$t\$\>/$text_hash{$t}/ges;
	}

	# 出力
	print &http_header;
	print $template;
}


#-------------------------------------------------------------------
# RPC Request
#-------------------------------------------------------------------


#	&get_date(rna=>$friend_rna_uri, rpc=>$friend_rna_xmlrpc_uri);
sub get_date
{
	my %arg = @_;
	my $rna_uri = $arg{rna};
	my $rpc_uri = $arg{rpc};
	
	my $result = eval{XMLRPC::Lite->proxy($rpc_uri)->call('rna.getDate')->result};
	if($@) {
		$rna->error_log(message=>$@, die=>1);
	}

	print &http_header(type=>'text/plain');
	print 'Updated at ' . $result;
}

#	&compare_sites(rna=>$friend_rna_uri, rpc=>$friend_rna_xmlrpc_uri);
sub compare_sites
{
	my %arg = @_;
	my $rna_uri = $arg{rna};
	my $rpc_uri = $arg{rpc};

	my $result = eval{XMLRPC::Lite->proxy($rpc_uri)->call('rna.getSites')->result};
	if($@) {
		$rna->error_log(message=>$@, die=>1);
	}

	# ローカルRNAのサイトリストのチェック
	my $own_rss = new RNA::RSS;
	$own_rss->parsefile($config->{SiteList}->{File});
	my %exist_uri = ();
	my $local_site_num = scalar(@{$own_rss->{items}});
	foreach my $item (@{$own_rss->{items}}) {
		$exist_uri{escape_uri($item->{link})} = 1;
		# はてなを除く
		$local_site_num-- if($item->{dc}->{subject} eq $config->{HatenaFlag});
	}

	# 相手RNAのサイトリストを，ローカルにあるものとないもので分類
	my $not_exist_rss = new RNA::RSS;
	my $exist_rss = new RNA::RSS;
	my $remote_site_num = 0;
	foreach my $site (@{$result}) {
		my $item = {
			title => encode($site->{title})||'',
			link  => escape_uri($site->{link})||'',
			description => encode($site->{description})||'',
			dc => {
				subject => encode($site->{subject})||'',
				creator => encode($site->{creator})||''
			}
		};

		# はてなを除く
		next if($item->{dc}->{subject} eq $config->{HatenaFlag});
		if(exists $exist_uri{$item->{link}}) {
			$exist_rss->add_item(%{$item});
		}
		else {
			$not_exist_rss->add_item(%{$item});
		}

		$remote_site_num++;
	}

	#-------------------------------
	# Result Page の作成
	#-------------------------------
	&set_rss($not_exist_rss, 
		'RNA::Alliance::Compare', 
		$self_uri_with_query, 'Target : ' . $rna_uri, $rna->{Date}, 
		$config->{Owner}, $config->{Language});

	my %text_hash = %{$config->{Template}->{Element}};
	$text_hash{RNAAllianceTargetURI} = $rna_uri;
	$text_hash{RNAAllianceCommonSiteNum} = scalar(@{$exist_rss->{items}});
	$text_hash{RNAAllianceNotCommonSiteNum}=scalar(@{$not_exist_rss->{items}});
	$text_hash{RNAAllianceLocalSiteNum} = $local_site_num;
	$text_hash{RNAAllianceRemoteSiteNum} = $remote_site_num;

	# template の分離
	my $template = &read_file($config->{Template}->{AllianceCompare});
	my ($not_exist_template, $exist_template)
		= split('<!--__SEPARATOR_COMMON_AND_NOT_COMMON__-->', $template);

	my $page_str = '';
	# ローカルに無いサイトのリスト
	{
		my $antenna = new RNA::AntennaTree;
		$antenna->set_from_rss($not_exist_rss);
		my $str_ref = 
			$antenna->apply_template($not_exist_template, \%text_hash);
		$page_str .= $$str_ref;
	}

	# 共通のサイトのリスト
	{
		my $antenna = new RNA::AntennaTree;
		$antenna->set_from_rss($exist_rss);
		my $str_ref = 
			$antenna->apply_template($exist_template, \%text_hash);
		$page_str .= $$str_ref;
	}

	# log
	$rna->info_log(message=>"compare_sites with $rna_uri");

	print &http_header;
	print $page_str;
}


#-------------------------------------------------------------------
# Request for third-party engine
#-------------------------------------------------------------------

#	&search_sites(engine=>'bulkfeeds', keyword=>'keyword', field=>'title');
#		field : title , link, description
sub search_sites
{
	my %arg = @_;
	my $engine = $arg{engine};

	my $rss = new RNA::RSS;
	if(lc($engine) eq 'bulkfeeds') {
		my $q = $arg{keyword};
		my $field = $arg{field};

		my $bulkfeeds = new RNA::Net::Bulkfeeds;
		my $opml_str 
			= $bulkfeeds->search_sites(type=>'opml', q=>$q, field=>$field);

		require RNA::OPML;
		my $opml = new RNA::OPML(encoding=>$config->{Encoding});
		eval{ $opml->parse($opml_str); };
		$rss = $opml->to_rss($rss);
	}

	#-------------------------------
	# Result Page の作成
	#-------------------------------
	&set_rss($rss, 
		'RNA::Site::Search', 
		$self_uri_with_query, 'Engine : ' . $engine, $rna->{Date}, 
		$config->{Owner}, $config->{Language});

	my %text_hash = %{$config->{Template}->{Element}};
	my $template = &read_file($config->{Template}->{SiteSearchResult});
	my $str_ref = RNA::AntennaTree::apply_template_to_rss($rss, $template, \%text_hash);

	# log
	$rna->info_log(message=>"search sites by $engine");

	print &http_header;
	print $$str_ref;
}



# $str = escape_uri($str)
sub escape_uri { return RNA::RSS::WebEdit::escape_uri(@_);}

# $str = encode($str)
sub encode {return html_encode_minimal(@_);}

# $header = &http_header(type=>'text/html');
sub http_header
{
	my %hash = @_;
	my $type = $hash{type} || 'text/html';

	return $cgi->header(-type=>$type, -charset => $config->{Encoding});
}
