#!/usr/bin/perl
#=============================================================================
# RNA Authentication
#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
#
# ./rna-auth.cgi?mode=xxx&transfer=http://xxx/
#	という形式で呼び出す
#
#=============================================================================

# ライブラリ
use strict;
use lib qw(lib extlib);
use CGI;
use RNA;
use RNA::Auth;
use RNA::Utils qw(:all);
use RNA::Session;

my $cgi = new CGI;

#----------------------------------
# 基本設定
#----------------------------------
my $self_uri = $cgi->url(-relative=>1);
my $self_uri_with_query = $cgi->self_url;

#==============================================================================
# main
#==============================================================================

# RNA Object
my $rna = RNA->new(Config => './config.pl');
my $config = $rna->{Config};


#-----------------------------------
# モードの設定
#-----------------------------------
my $mode = $cgi->param('mode') ? $cgi->param('mode') : 'main';

#-----------------------------------
# リダイレト先のURI
#-----------------------------------
my $transfer_uri = $cgi->param('transfer') 
	? $cgi->param('transfer') : $cgi->referer() ;
$transfer_uri = 
	$transfer_uri ? $transfer_uri 
		: $rna->{Config}->{MainIndex}->{URI};


#-----------------------------------
# 実行
#-----------------------------------
if   ($mode eq 'login') {
# 認証
# 正しければ、transfer の URI に飛ぶ
	&authenticate(cgi=>$cgi, transfer=>$transfer_uri);
}
if   ($mode eq 'logout') {
# ログアウト
	&logout(cgi=>$cgi, transfer=>$transfer_uri);
}
else {
# main ページ
	&show_login_page(transfer=>$transfer_uri);
}

#=============================================================================
# サブルーチン
#=============================================================================

# 	&show_login_page(transfer=>$transfer_uri);
sub show_login_page
{
	my %hash = @_;
	my $transfer_uri = $hash{transfer} || $config->{MainIndex}->{URI};
	my $auth = eval{$rna->get_auth;};
	&die_handler($@) if($@);

	my $template = &read_file($config->{Template}->{Login});
	foreach my $t (keys %{$config->{Template}->{Element}}){
		$template =~ s/<\$$t\$>/$config->{Template}->{Element}->{$t}/ges;
	}

	print $auth->login_page(transfer=>$transfer_uri, template=>$template);
	exit;
}


# 認証
#
# authenticate(cgi=>$cgi, transfer=>$self_uri);
#	$cgi : CGI オブジェクト
sub authenticate
{
	my %hash = @_;
	my $cgi = $hash{cgi};
	my $transfer_uri = $hash{transfer};
	my $auth = eval{$rna->get_auth;};
	&die_handler($@) if($@);

	# Cookie
	my $cookie = $auth->login_cookie($cgi->param(&RNA::Auth::username_label), 
		$cgi->param(&RNA::Auth::passwd_label) );

	if($rna->authenticate(cgi=>$cgi)){
#print "Content-type: text/plain\n\n". $cgi->param('username');;
	# Authorized
		print $cgi->redirect(-uri=>$transfer_uri, -cookie=>$cookie);
		$rna->info_log(message=>"Login");
	}
	else {
	# Not Authorized
		print $cgi->redirect("$self_uri?transfer=".url_encode($transfer_uri));
	}
}


# ログアウト
#
# logout(cgi=>$cgi, transfer=>$self_uri);
#	$cgi : CGI オブジェクト
sub logout
{
	my %hash = @_;
	my $cgi = $hash{cgi};
	my $transfer_uri = $hash{transfer};
	my $auth = eval{$rna->get_auth;};
	&die_handler($@) if($@);

	# Cookie
	my $cookie = $auth->logout_cookie;

#print "Content-type: text/plain\n\n". $cgi->param('username');;
	print $cgi->redirect(-uri=>$transfer_uri, -cookie=>$cookie);

	$rna->info_log(message=>"Logout");
}





