#!/usr/bin/perl
#=============================================================================
# RNA Clip
#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
# Copyright (C) 2003,2004           Masahiro Hamasaki, All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
#
# RSS Clip の編集を行うスクリプト
#
#=============================================================================

# ライブラリ
use strict;
use lib qw(lib extlib);
use CGI;

use RNA::RSS;
use RNA;
use RNA::Utils qw(:all);
use RNA::AntennaTree;
use RNA::RSS::WebEdit;

my $cgi = new CGI;
$cgi->param;
&die_handler($cgi->cgi_error) if ($cgi->cgi_error);

#----------------------------------
# 基本設定
#----------------------------------
my $self_uri = $cgi->url(-relative=>1);
my $self_uri_with_query = $cgi->self_url;

#==============================================================================
# main
#==============================================================================

my $rna = RNA->new(Config => './config.pl');
my $config = $rna->{Config};
my $clip_rss_file = $config->{ClipList}->{RSS};

#----------------------------------
# 認証
#----------------------------------
if($config->{Authentication}->{ClipCGI}) {
	unless($rna->authenticate(cgi=>$cgi)){
		print $cgi->redirect($config->{AuthenticationCGIURI} 
					. '?transfer=' . url_encode($self_uri_with_query));
		exit;
	}
}


my $referer = $cgi->referer();
my $transfer_uri = $referer ? $referer : $rna->{Config}->{ClipCGIURI};


if($cgi->param('target') eq 'update_clip_list'){

	my %hash = ();
	my @param_list = qw(action select link title source sourceURL date creator 
							description subject dc_description);
	foreach my $param (@param_list) {
		$hash{$param} = $cgi->param($param);
		if($param =~ /^(select|link|sourceURL)$/) {
			$hash{$param} = &url_encode_minimal($hash{$param});
		}
	}
#print "Content-type: text/plain; charset=UTF-8\n\n";
#map {print "$_ : $hash{$_} \n"} keys %hash;

	foreach my $key (qw(title)){
		unless($hash{$key}){
			$hash{$key} = $config->empty_value;
		}
	}
	
	&update_clip_list(%hash);
}
else{
	&show_clip_config_page;
}


#=============================================================================
# Sub routine
#=============================================================================

# &update_clip_list(%hash);
sub update_clip_list
{
	my %arg = @_;

	# リストの取り出し
	my $list_rss = new RNA::RSS;
	$list_rss->parsefile($clip_rss_file);

	my $err_msg = &RNA::RSS::WebEdit::update_rss($list_rss, \%arg, 'front');
	if($err_msg) {
		$rna->error_log(message=>$err_msg, die=>'1');
	}

	#-------------------------------------
	# 出力
	#-------------------------------------
	&set_clip_list($clip_rss_file, $list_rss);
	my $template = read_file($config->{Template}->{ClipList});
	my $str_ref = RNA::AntennaTree::apply_template_to_rss($list_rss, 
		$template, $config->{Template}->{Element});
	print_file($config->{ClipList}->{HTML}, $str_ref);
	
	#-----------------------------------
	# 元のURIへのリダイレクション
	#-----------------------------------
	if($referer =~ $self_uri){
	# 自分自身からの遷移
		print $cgi->redirect($transfer_uri);
	}
	else{
	# 他のページから
		print &result_page($transfer_uri, \%arg);
	}

	# log
	$rna->info_log(message=>$arg{action} . " clip" );
}


# &set_clip_list($file, $rss)
sub set_clip_list
{
	my ($file, $rss) = @_;
	
	&set_rss($rss,
		$config->{ClipList}->{Title},
		$config->{BaseURI} . $config->{ClipList}->{HTML},
		$config->{ClipList}->{Description},
		$rna->{Date},
		$config->{Owner},
		$config->{Language});
	my $str = $rss->as_string;
	&print_file($file, \$str);
}


#-----------------------------------
# Clip configure ページ
#-----------------------------------
#	&show_clip_config_page;
sub show_clip_config_page
{
	# Clip リストの取り出し
	my $list_rss = new RNA::RSS;
	$list_rss->parsefile($clip_rss_file);

	# テンプレート
	my $template = &read_file($config->{Template}->{ClipConfigure});
	my %text_hash = %{$config->{Template}->{Element}};

	print &RNA::RSS::WebEdit::show_configure_page(
		$list_rss, $template, \%text_hash);

}


# $html = &result_page($transfer_uri, \%hash);
sub result_page
{
	my $transfer_uri = shift;
	my $hash_ref = shift;
	my %hash = %{$hash_ref};

	my @list =qw(title link description date creator subject source sourceURL dc_description);
	my $data = 
		"<table border=\"1px\" cellspacing=\"0\" cellpadding=\"4\">\n"
		. join('', map{"<tr><td>$_</td><td>" . RNA::RSS::WebEdit::encode($hash{$_}) . "</td></tr>\n"} @list)
		. "</table>\n";

	my $header = CGI->new->header(-type=>'text/html', 
		-charset => $config->{Encoding});
	my $clip_html_uri = $config->{ClipList}->{HTML};
	my $clip_rss_uri  = $config->{ClipList}->{RSS};
	my $conf_cgi_uri = $config->{ClipCGIURI};
	my $css_uri = $config->{BaseURI} . $config->{CSSStyleSheet};
	my $jscript_uri = $config->{BaseURI} . $config->{JavaScript};

	return qq($header
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title>Clip Updated</title>
		<link rel="stylesheet" href="$css_uri" type="text/css" />
		<script type="text/javascript" src="$jscript_uri"></script>
	</head>
	<body>
		<div id="banner">
		<h1>RNA::Clip Updated</h1>
		<span class="description">Request : $hash{action}</span>
		</div>
		<div id="content">
		<div class="blog">
		<h2 class="date">Clipped Entry</h2>
		<br />
		<table border="0" cellpadding="4" cellspacing="0">
		<tr>
		<td><span class="file"><a href="$clip_rss_uri">RSS</a></span></td>
		<td><span class="file"><a href="$clip_html_uri">HTML</a></span></td>
		</tr>
		</table>
		<br />
		$data
		<br />
		
		<form action="$conf_cgi_uri" method="get">
		<input type="submit" value="Config Clips" alt="Config Clips" />
		</form>
		
		<form action="$transfer_uri" method="get">
		<input type="submit" value="Back" alt="Back" />
		</form>
		
		</div>
		</div>
	</body>
</html>
);
}
