#!/usr/bin/perl
#=============================================================================
# RNA Refresh Tool
#=============================================================================
#
#
#=============================================================================
# Copyright (C) 2003,2004           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
# Usage:
# 	perl ./rna-refresh.pl                  # refresh antenna
#	perl ./rna-refresh.pl --refresh        # refresh antenna
#	perl ./rna-refresh.pl --linktrace      # trace trackbacks and links
#==============================================================================

# library
use strict;
use lib qw(lib extlib);
use RNA;
use Carp;


#==============================================================================
# main
#==============================================================================

# RNA Object
my $rna = RNA->new(Config => './config.pl');
my $config = $rna->{Config};

# arguments
my $opt = @ARGV[0];
my $uri = '';
if    ($opt eq '--refresh') {
	$uri = $config->{UpdateCGIURI};
}
elsif ($opt eq '--linktrace') {
	$uri = $config->{CacheCGIURI};
}
else {
	$uri = $config->{UpdateCGIURI};
}


eval { &request(uri=>$uri); };
die $@ . "\n" if($@);


#=============================================================================
# sub routine
#=============================================================================

# &request(uri=>$uri)
sub request
{
	my %arg = @_;
	my $uri = $arg{uri};

	require HTTP::Lite;
	my $http = new HTTP::Lite;
	if ($http->request($uri) == 200) {
		return 1;
	}
	else {
		croak "Request failed: " . $http->status_message() . "\n";
	}
}


